AgeStatus class

Container for an age related scanning statuses.

Constructors

AgeStatus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
over18 → CheckResult
no setter
over21 → CheckResult
no setter
over25 → CheckResult
no setter
over65 → CheckResult
no setter
overThreshold → CheckResult
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold → int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → AgeStatus?
Allows you to deserialize object.