Application class

Structure is used to describe the contents of a single LDS applica-tion and their analysis within the context of the communication session with electronic document.

Constructors

Application()

Properties

applicationID → String?
Application identifier.
no setter
dataHashAlgorithm → String?
Algorithm for calculating hash values for files for the proce-dure of PA.
no setter
files → List<File>
List of containers to store information about the read files of the application.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → RFIDErrorCodes
Status of the application selection procedure.
no setter
type → RFIDApplicationType
Type of application of electronic document.
no setter
unicodeVersion → String?
Unicode version for application.
no setter
version → String?
Application version.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Application?
Allows you to deserialize object.