AuthenticityCheck class

Constructors

AuthenticityCheck()

Properties

elements → List<AuthenticityElement>
no setter
hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CheckResult
Indicates verification result.
no setter
type → Authenticity
Indicates verification type result.
no setter
typeName → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → AuthenticityCheck?
Allows you to deserialize object.