AuthenticityParams class

Constructors

AuthenticityParams()

Properties

checkAxial ↔ bool?
getter/setter pair
checkBarcodeFormat ↔ bool?
getter/setter pair
checkExtMRZ ↔ bool?
getter/setter pair
checkExtOCR ↔ bool?
getter/setter pair
checkFibers ↔ bool?
getter/setter pair
checkImagePatterns ↔ bool?
getter/setter pair
checkIPI ↔ bool?
getter/setter pair
checkIRB900 ↔ bool?
getter/setter pair
checkIRVisibility ↔ bool?
getter/setter pair
checkLetterScreen ↔ bool?
getter/setter pair
checkPhotoComparison ↔ bool?
getter/setter pair
checkPhotoEmbedding ↔ bool?
getter/setter pair
checkProperties ↔ bool?
Set to true to enable detection of the document properties, such as holder's signature and other attributes.
getter/setter pair
checkSecurityText ↔ bool?
getter/setter pair
checkUVLuminiscence ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
livenessParams ↔ LivenessParams
getter/setter pair
propertiesParams ↔ AuthenticityPropertiesParams
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testSetters ↔ Map<String, dynamic>
getter/setter pair
useLivenessCheck ↔ bool?
This parameter is used to enable document liveness check.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → AuthenticityParams
Allows you to deserialize object.