AuthenticityPropertiesParams class
Properties
-
Set to true to enable detection of the document holder’s signature.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
testSetters
↔ Map<String, dynamic>
-
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Allows you to serialize object.
-
toString()
→ String
-
A string representation of this object.
inherited