BackendProcessingConfig class

Constructors

BackendProcessingConfig(String url, {bool? rfidServerSideChipVerification, bool? mdlVerification, Map<String, String>? httpHeaders, double? timeoutConnection})

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpHeaders → Map<String, String>?
no setter
mdlVerification → bool?
no setter
rfidServerSideChipVerification → bool?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutConnection → double?
Timeout in seconds that can be configured for backend transaction creation and package finalization.
no setter
url → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → BackendProcessingConfig?
Allows you to deserialize object.