BarcodeField class

Structure describing single value of the field.

Constructors

BarcodeField()

Properties

barcodeType → BarcodeType
Decoded barcode type.
no setter
data → Uint8List?
Results of reading data from barcode modules.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
Indicates an index of the document page, whence the result is received.
no setter
pdf417Info → PDF417Info?
Contains the information about the PDF417 barcode.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → BarcodeStatus
Indicates barcode reading result.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → BarcodeField?
Allows you to deserialize object.