CameraMode enum

Inheritance
Available extensions

Values

UNKNOWN → const CameraMode

Will be returned if getByValue if a non-existent was passed.

const CameraMode(-1)
AUTO → const CameraMode
const CameraMode(0)
CAMERA1 → const CameraMode
const CameraMode(1)
CAMERA2 → const CameraMode
const CameraMode(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getByValue(int? i) → CameraMode?

Constants

values → const List<CameraMode>
A constant List of the values in this enum, in order of their declaration.