CaptureMode enum

Inheritance
Available extensions

Values

UNKNOWN → const CaptureMode

Will be returned if getByValue if a non-existent was passed.

const CaptureMode(-1)
AUTO → const CaptureMode

A flow of frames is taken for recognition right after a scenario is started.

const CaptureMode(0)
CAPTURE_VIDEO → const CaptureMode

A flow of frames is taken for recognition right after the Capture button is pushed.

const CaptureMode(1)
CAPTURE_FRAME → const CaptureMode

A single frame is taken for recognition right after the Capture button is pushed.

const CaptureMode(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getByValue(int? i) → CaptureMode?

Constants

values → const List<CaptureMode>
A constant List of the values in this enum, in order of their declaration.