CardProperties class

Constructors

CardProperties()

Properties

aTQA ↔ int?
getter/setter pair
aTQB ↔ String?
getter/setter pair
aTR ↔ String?
getter/setter pair
baudrate1 ↔ String?
getter/setter pair
baudrate2 ↔ String?
getter/setter pair
bitRateR ↔ int?
getter/setter pair
bitRateS ↔ int?
getter/setter pair
chipTypeA ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mifareMemory ↔ int?
getter/setter pair
rfidType ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sAK ↔ int?
getter/setter pair
support4 ↔ bool?
getter/setter pair
supportMifare ↔ bool?
getter/setter pair
uID ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CardProperties?