CertificateChain class

Constructors

CertificateChain()

Properties

extensions → List<Extension>
no setter
fileName → RFIDValue?
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuer → Authority?
no setter
notifications → List<int>
no setter
origin → int
no setter
paStatus → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String?
no setter
signatureAlgorithm → String?
no setter
subject → Authority?
no setter
subjectPKAlgorithm → String?
no setter
type → RFIDCertificateType
Define the type of certificate used in the procedure of document security object digital signature verification.
no setter
validity → RFIDValidity?
no setter
version → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CertificateChain?
Allows you to deserialize object.