Customization class

Params that relate to the camera view controller customization and etc.

Constructors

Customization()

Properties

activityIndicatorColor ↔ Color?
Allows you to set a color for the activity indicator.
getter/setter pair
activityIndicatorLandscapePositionMultiplier ↔ double?
Allows you to set an offset for the activity indicator (landscape orientation). If not set, activity indicator always centered in the camera border.
getter/setter pair
activityIndicatorPortraitPositionMultiplier ↔ double?
Allows you to set an offset for the activity indicator (portrait orientation). If not set, activity indicator always centered in the camera border.
getter/setter pair
backgroundMaskAlpha ↔ double?
Allows you to set intensity of the background mask.
getter/setter pair
backgroundMaskColor ↔ Color?
Allows you to set color for background mask area.
getter/setter pair
borderBackgroundImage ↔ ByteData?
Allows you to set any image within the camera frame.
getter/setter pair
borderBackgroundImageTransformsAndroid ↔ List<double>?
Matrix used to scale the view within the camera frame.
getter/setter pair
borderBackgroundImageTransformsIOS ↔ ViewContentMode?
Allows you to specify how a view within the camera frame adjusts its content when its size changes.
getter/setter pair
cameraFrameActiveColor ↔ Color?
Allows you to set a color for the camera frame when a document is detected.
getter/setter pair
cameraFrameBorderWidth ↔ int?
Allows you to set thickness of the camera frame borders.
getter/setter pair
cameraFrameCornerRadius ↔ double?
Allows you to set a corner radius of the camera frame.
getter/setter pair
cameraFrameDefaultColor ↔ Color?
Allows you to set a color for the camera frame when a document is out of the camera frame or is not detected.
getter/setter pair
cameraFrameLandscapeAspectRatio ↔ double?
Allows you to set an aspect ratio of the camera frame (landscape orientation). Default: 0.
getter/setter pair
cameraFrameLineCap ↔ Cap?
Allows you to customize the beginning and ending of stroked lines of the camera frame.
getter/setter pair
cameraFrameLineLength ↔ int?
Allows you to set length of the lines of the camera frame.
getter/setter pair
cameraFrameOffsetWidth ↔ int?
Allows you to set an offset for the camera frame (portrait orientation).
getter/setter pair
cameraFramePortraitAspectRatio ↔ double?
Allows you to set an aspect ratio of the camera frame (portrait orientation).
getter/setter pair
cameraFrameShapeType ↔ FrameShapeType?
Allows you to set a shape type for the camera frame.
getter/setter pair
cameraFrameVerticalPositionMultiplier ↔ double?
Allows you to change the location of the camera frame vertically. Default: 1.
getter/setter pair
cameraPreviewBackgroundColor ↔ Color?
Allows you to set a background color for the camera preview (top and bottom frames).
getter/setter pair
cameraPreviewVerticalPositionMultiplier ↔ double?
Allows you to change the vertical offset of the camera preview layer. If you need to raise the layer 50% of its height up, then you specify 0.5. If you need to lower the layer 75% of its height, then enter 1.75. Valid values: from 0 (the layer will be raised completely up) to 2 (the layer will be completely lowered down).
getter/setter pair
cameraSwitchButtonImage ↔ ByteData?
Allows you to set any image for the button that allows changing positions of the capture device.
getter/setter pair
captureButtonImage ↔ ByteData?
Allows you to set any image for the capture button.
getter/setter pair
changeFrameButtonCollapseImage ↔ ByteData?
Allows you to set any image for the button that allows changing shapes of the camera (collapsed state).
getter/setter pair
changeFrameButtonExpandImage ↔ ByteData?
Allows you to set any image for the button that allows changing shapes of the camera (expanded state).
getter/setter pair
closeButtonImage ↔ ByteData?
Allows you to set any image for the close button.
getter/setter pair
colors ↔ CustomizationColors
getter/setter pair
contentModes ↔ CustomizationContentModes
getter/setter pair
customLabelStatus ↔ String?
Allows you to create a custom status.
getter/setter pair
customStatusPositionMultiplier ↔ double?
Allows you to change the location of the custom status.
getter/setter pair
fonts ↔ CustomizationFonts
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
helpAnimationImage ↔ ByteData?
Allows you to set any image for the help animation.
getter/setter pair
helpAnimationImageTransformsAndroid ↔ List<double>?
Matrix used to scale help animation.
getter/setter pair
helpAnimationImageTransformsIOS ↔ ViewContentMode?
Allows you to specify how a view of the help animation adjusts its content when its size changes.
getter/setter pair
images ↔ CustomizationImages
getter/setter pair
livenessAnimationImage ↔ ByteData?
Allows you to set any image for the liveness animation.
getter/setter pair
livenessAnimationImageTransformsAndroid ↔ List<double>?
Matrix used to scale liveness animation.
getter/setter pair
livenessAnimationImageTransformsIOS ↔ ViewContentMode?
Allows you to specify how a view of the liveness animation adjusts its content when its size changes.
getter/setter pair
livenessAnimationPositionMultiplier ↔ double?
Allows you to change the location of the liveness animation.
getter/setter pair
matrices ↔ CustomizationMatrices
getter/setter pair
multipageAnimationBackImage ↔ ByteData?
Allows you to set any image for the multipage animation (back side).
getter/setter pair
multipageAnimationBackImageTransformsAndroid ↔ List<double>?
Matrix used to scale multipage animation (back side).
getter/setter pair
multipageAnimationBackImageTransformsIOS ↔ ViewContentMode?
Allows you to specify how a view of the multipage animation (back side) adjusts its content when its size changes.
getter/setter pair
multipageAnimationFrontImage ↔ ByteData?
Allows you to set any image for the multipage animation (front side).
getter/setter pair
multipageAnimationFrontImageTransformsAndroid ↔ List<double>?
Matrix used to scale multipage animation (front side).
getter/setter pair
multipageAnimationFrontImageTransformsIOS ↔ ViewContentMode?
Allows you to specify how a view of the multipage animation (front side) adjusts its content when its size changes.
getter/setter pair
multipageButtonBackgroundColor ↔ Color?
Allows you to set a color for the "Skip next page" button.
getter/setter pair
multipageButtonImage ↔ ByteData?
Allows you to set any UIImage for the "Skip next page" button.
getter/setter pair
multipageButtonPositionMultiplier ↔ double?
Allows you to change the location of the multipage button.
getter/setter pair
multipageButtonText ↔ String?
getter/setter pair
multipageButtonTextColor ↔ Color?
getter/setter pair
multipageButtonTextFont ↔ Font?
getter/setter pair
nextPageAnimationEndDelay ↔ double?
Animation delay after flip.
getter/setter pair
nextPageAnimationStartDelay ↔ double?
Animation delay before flip.
getter/setter pair
resultStatus ↔ String?
Allows you to set any string to the result status.
getter/setter pair
resultStatusBackgroundColor ↔ Color?
Allows you to set a color of the background for the result status messages.
getter/setter pair
resultStatusPositionMultiplier ↔ double?
Allows you to change the location of the result status.
getter/setter pair
resultStatusTextColor ↔ Color?
Allows you to set a color for the result status messages.
getter/setter pair
resultStatusTextFont ↔ Font?
Allows you to set a font for the result status messages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBackgroundMask ↔ bool?
If it's set to true, the background mask next to the camera frame will be displayed.
getter/setter pair
showHelpAnimation ↔ bool?
If it's set to true, the animation showing how to position a document will be displayed.
getter/setter pair
showNextPageAnimation ↔ bool?
If it's set to true, the animation asking for processing the next page will be displayed.
getter/setter pair
showResultStatusMessages ↔ bool?
If it's set to true, result status messages during the document processing will be shown.
getter/setter pair
showStatusMessages ↔ bool?
If it's set to true, status messages during the document processing will be shown.
getter/setter pair
status ↔ String?
Allows you to set any string to the status.
getter/setter pair
statusBackgroundColor ↔ Color?
Allows you to set a background color for the status messages.
getter/setter pair
statusPositionMultiplier ↔ double?
Allows you to change the location of the status.
getter/setter pair
statusTextColor ↔ Color?
Allows you to set a color for the status messages.
getter/setter pair
statusTextFont ↔ Font?
Allows you to set a font for the status messages.
getter/setter pair
testSetters ↔ Map<String, dynamic>
getter/setter pair
theme ↔ CustomizationTheme?
Allows you to set a visual theme for buttons controls.
getter/setter pair
timings ↔ CustomizationTimings
getter/setter pair
tintColor ↔ Color?
Allows you to set a color for all visual elements.
getter/setter pair
toolbarSize ↔ double?
Allows you to set a size for the toolbar (it's where all buttons are located).
getter/setter pair
torchButtonOffImage ↔ ByteData?
Allows you to set any image for the torch button when its state is OFF.
getter/setter pair
torchButtonOnImage ↔ ByteData?
Allows you to set any image for the torch button when its state is ON.
getter/setter pair
uiCustomizationLayer ↔ Map<String, dynamic>?
JSON structure defining labels and graphic elements to be added to the Camera UI.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Customization
Allows you to deserialize object.