helpAnimationImageTransformsIOS property
- @Deprecated("Use `images.helpAnimation` instead.")
Allows you to specify how a view of the help animation adjusts its content when its size changes.
Default: ViewContentMode.SCALE_ASPECT_FIT.
IOS only. For Android use helpAnimationImageTransformsAndroid.
Implementation
@Deprecated("Use `images.helpAnimation` instead.")
ViewContentMode? get helpAnimationImageTransformsIOS =>
_helpAnimationImageTransformsIOS;
set
helpAnimationImageTransformsIOS
(ViewContentMode? val)
Implementation
set helpAnimationImageTransformsIOS(ViewContentMode? val) {
_helpAnimationImageTransformsIOS = val;
_set({"helpAnimationImageContentMode": val?.value});
}