CustomizationFonts class

Constructors

CustomizationFonts()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mdlEnableNfcButtonText ↔ Font?
Android only.
getter/setter pair
mdlEnableNfcDescriptionText ↔ Font?
Android only.
getter/setter pair
mdlEnableNfcTitleText ↔ Font?
Android only.
getter/setter pair
mdlProcessingScreenHintLabel ↔ Font?
getter/setter pair
mdlProcessingScreenProgressLabel ↔ Font?
getter/setter pair
mdlProcessingScreenResultLabel ↔ Font?
getter/setter pair
rfidEnableNfcButtonText ↔ Font?
Android only.
getter/setter pair
rfidEnableNfcDescriptionText ↔ Font?
Android only.
getter/setter pair
rfidEnableNfcTitleText ↔ Font?
Android only.
getter/setter pair
rfidProcessingScreenHintLabel ↔ Font?
getter/setter pair
rfidProcessingScreenProgressLabel ↔ Font?
getter/setter pair
rfidProcessingScreenResultLabel ↔ Font?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testSetters ↔ Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CustomizationFonts
Allows you to deserialize object.