DocReaderScenario class

Constructors

DocReaderScenario()

Properties

caption → String
string representation of scenario ID.
no setter
description → String
Description of the scenario.
no setter
faceExt → bool
no setter
frameKWHDoublePageSpreadLandscape → double
no setter
frameKWHDoublePageSpreadPortrait → double
no setter
frameKWHLandscape → double
no setter
frameKWHPortrait → double
no setter
frameOrientation → DocReaderOrientation
Available orientation for scenario.
no setter
hashCode → int
The hash code for this object.
no setterinherited
manualCrop → bool
no setter
multiPageOff → bool
no setter
name → String
ID of the scenario.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesProcessMode → bool
no setter
uvTorch → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DocReaderScenario?