DocReaderVersion class

Class contains properties to get the information about the SDK.

Constructors

DocReaderVersion()

Properties

api → String?
A version of the API framework.
no setter
core → String?
A version of the Core framework.
no setter
coreMode → String?
A type of the Core framework.
no setter
database → DocumentsDatabase?
A version of the database.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DocReaderVersion?