DocumentReader class

Entry point of the Regula DocumentReader SDK.

Properties

availableScenarios → List<DocReaderScenario>
A list of scenarios that can be used for documents recognition based on your license and Core framework capabilities.
no setter
customization ↔ Customization
Params that relate to the camera view controller customization and etc.
getter/setter pair
env ↔ String?
Environment type.
getter/setter pair
functionality ↔ Functionality
Params that influence the scanning process, camera view controller customization and etc.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticatorAvailableForUse → Future<bool>
Allows you to check if you can use external Regula Bluetooth devices based on your license, available scenarios and Core framework capabilities.
no setter
isAuthenticatorRFIDAvailableForUse → Future<bool>
Allows you to check if you can use external Regula Bluetooth devices based on your license and Core framework capabilities.
no setter
isReady → Future<bool>
Allows you to check if Document Reader is ready for use.
no setter
license → License
Information about your license.
no setter
locale ↔ String?
Custom language locale code of DocumentReaderSDK. If empty or doesn't exist - app language is used. Format "en-US" or "en".
getter/setter pair
localizationDictionary ↔ Map<String, String>?
A localization dictionary to override default localization logic. Allows to replace any string of DocumentReader SDK with an arbitrary string.
getter/setter pair
onCustomButtonTapped ← CustomButtonTappedCompletion
no getter
processParams ↔ ProcessParams
Params that influence the scanning process.
getter/setter pair
rfidScenario ↔ RFIDScenario
Params that influence the RFID chip processing.
getter/setter pair
rfidSessionStatus ↔ String?
Allows you to get a status of the RFID chip reading process.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Future<String>
Allows you to get a status of Document Reader.
no setter
tag ↔ String?
Current Session identifier.
getter/setter pair
tenant ↔ String?
Customer name.
getter/setter pair
version → DocReaderVersion?
Information about the SDK.
no setter
videoEncoderCompletion ← VideoEncoderCompletion
Allows user to receive a video file of current session
no getter

Methods

addPKDCertificates(List<PKDCertificate> certificates) → void
Used to pass certificates to Document Reader that will be used during the RFID chip processing.
cancelDBUpdate() → Future<bool>
Allows you to cancel the database update.
checkDatabaseUpdate(String databaseID) → Future<DocumentsDatabase?>
Allows you to to check database update.
clearPKDCertificates() → void
It's used to remove certificates from your app that are used during the RFID chip processing.
connectBluetoothDevice(String deviceName) → Future<bool>
Used to connect to the ble device.
deinitializeReader() → void
Used to deinitialize Document Reader and free up RAM as a consequence of this.
endBackendTransaction() → void
It's used to end transaction during backend processing.
engageDevice(MDLDeviceEngagement type, {bool withoutUI = false, String? data}) → Future<(DeviceEngagement?, DocReaderException?)>
Used to engage device.
finalizePackage({FinalizeConfig? config}) → Future<FinalizePackageCompletion>
It's used to finalize package during backend processing.
initialize(InitConfig config) → Future<SuccessOrError>
Allows you to initialize Document Reader.
initializeReader(InitConfig config) → Future<SuccessOrError>
isRFIDAvailableForUse() → Future<bool>
Allows you to check if native RFID chip reading can be performed based on your license and Core framework capabilities.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareDatabase(String databaseID, DocumentReaderPrepareCompletion prepareCompletion) → Future<SuccessOrError>
Allows you to download a database from the Regula server. If it exists in your app and compatible with the SDK, it won't be downloaded.
readMDL(MDLDeviceEngagement type, DataRetrieval retrieval) → Future<(DocReaderAction, Results?, DocReaderException?)>
Used to read MDL.
recognize(RecognizeConfig config, DocumentReaderCompletion completion) → void
Used for proccessing predefined images.
removeDatabase() → Future<bool>
Allows you to remove the database from your app.
resetConfiguration() → void
Use this method to reset all parameters to their default values.
retrieveData(DataRetrieval retrieval, {MDLDeviceRetrieval? withoutUI, DeviceEngagement? engagement}) → Future<(DocReaderAction, Results?, DocReaderException?)>
Used to retrieve data.
rfid(RFIDConfig config) → void
Used for the RFID chip processing.
runAutoUpdate(String databaseID, DocumentReaderPrepareCompletion prepareCompletion) → Future<SuccessOrError>
Allows you to download a database from the Regula server. Each new update of the database will be downloaded.
scan(ScannerConfig config, DocumentReaderCompletion completion) → void
Used for multiple frames processing which are captured from the camera.
setTCCParams(TccParams params) → Future<SuccessOrError>
Sets the given TCCParams to the RFID session. The parameters are required to be set before starting RFID session.
startNewPage() → void
Used to start the processing of the next page of the document once the current one is processed.
startNewSession() → void
Used to start a scanning process.
startScanner(ScannerConfig config, DocumentReaderCompletion completion) → void
Used for multiple frames processing which are captured from the camera.
stopRFIDReader() → void
Used to stop the scanning process.
stopScanner() → void
Used to stop the scanning process.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → DocumentReader
The only instanse of singleton class DocumentReader.
no setter