removeDatabase method

Future<bool> removeDatabase()

Allows you to remove the database from your app.

Returns true only if the database was removed or absent.

Implementation

Future<bool> removeDatabase() async {
  return await _bridge.invokeMethod("removeDatabase", []);
}