DocumentReaderResults class

Constructors

DocumentReaderResults()

Properties

authenticityResult ↔ DocumentReaderAuthenticityResult?
getter/setter pair
barcodePosition ↔ List<ElementPosition?>
getter/setter pair
barcodeResult ↔ DocumentReaderBarcodeResult?
getter/setter pair
chipPage ↔ int?
getter/setter pair
documentPosition ↔ List<ElementPosition?>
getter/setter pair
documentReaderNotification ↔ DocumentReaderNotification?
getter/setter pair
documentType ↔ List<DocumentReaderDocumentType?>
getter/setter pair
elapsedTime ↔ int?
getter/setter pair
elapsedTimeRFID ↔ int?
getter/setter pair
graphicResult ↔ DocumentReaderGraphicResult?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highResolution ↔ bool?
getter/setter pair
imageQuality ↔ List<ImageQualityGroup?>
getter/setter pair
morePagesAvailable ↔ int?
getter/setter pair
mrzPosition ↔ List<ElementPosition?>
getter/setter pair
overallResult ↔ int?
getter/setter pair
processingFinishedStatus ↔ int?
getter/setter pair
rawResult ↔ String?
getter/setter pair
rfidResult ↔ int?
getter/setter pair
rfidSessionData ↔ RFIDSessionData?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textResult ↔ DocumentReaderTextResult?
getter/setter pair

Methods

findBySource(DocumentReaderTextField field, int sourceType) → DocumentReaderValue?
findByTypeAndLcid(int type, int lcid) → DocumentReaderTextField?
getGraphicFieldImageByType(int fieldType, {int source = -1, int pageIndex = -1, int light = -1}) → String?
getQualityResult(int imageQualityCheckType, {int securityFeature = -1, int pageIndex = 0}) → int?
getTextFieldStatusByType(int fieldType, {int lcid = 0}) → int?
getTextFieldValueByType(int fieldType, {int lcid = 0, int source = -1, bool original = false}) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DocumentReaderResults?