DocumentReaderScenarioFull class

Properties

caption ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
faceExt ↔ bool?
getter/setter pair
frameKWHDoublePageSpreadLandscape ↔ double?
getter/setter pair
frameKWHDoublePageSpreadPortrait ↔ double?
getter/setter pair
frameKWHLandscape ↔ double?
getter/setter pair
frameKWHPortrait ↔ double?
getter/setter pair
frameOrientation ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualCrop ↔ bool?
getter/setter pair
multiPageOff ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesProcessMode ↔ bool?
getter/setter pair
uvTorch ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DocumentReaderScenarioFull?