DocumentReaderTextField class

Constructors

DocumentReaderTextField()

Properties

fieldName ↔ String?
getter/setter pair
fieldType ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lcid ↔ int?
getter/setter pair
lcidName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int?
getter/setter pair
value ↔ DocumentReaderValue?
getter/setter pair
values ↔ List<DocumentReaderValue?>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DocumentReaderTextField?