DocumentsDatabase class

Class contains properties to get the information about the database.

Constructors

DocumentsDatabase()

Properties

countriesNumber → int
A number of countries included in the database.
no setter
databaseDescription → String?
A list of supported documents in the database.
no setter
databaseID → String?
An ID of the database, e.g. BLR, RUS.
no setter
date → String?
A date when the database was created.
no setter
documentsNumber → int
A number of documents included in the database.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
Database size. In bytes. Available for database update check.
no setter
version → String?
A version of the database.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DocumentsDatabase?