FaceApiParams class

Constructors

FaceApiParams({String url = "https://faceapi.regulaforensics.com", String mode = "match", int threshold = 75, FaceApiSearchParams? searchParams, int serviceTimeout = 3000, String? proxy, String? proxyPassword, int? proxyType, String? livenessTransactionId})

Properties

hashCode → int
The hash code for this object.
no setterinherited
livenessTransactionId → String?
This parameter allows you to use a liveness transaction id instead of a selfie photo.
no setter
mode → String
The processing mode: "match" or "match+search".
no setter
proxy → String?
Proxy to use, should be set according to the cURL standart.
no setter
proxyPassword → String?
Username and password to use for proxy authentication, should be set according to the cURL standart.
no setter
proxyType → int?
Proxy protocol type, should be set according to the cURL standart.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchParams → FaceApiSearchParams?
A search filter that can be applied if the "match+search" mode is enabled.
no setter
serviceTimeout → int
The service request timeout, ms.
no setter
threshold → int
The similarity threshold, 0-100. Above 75 means that the faces' similarity is verified, below 75 is not.
no setter
url → String
The URL of the Regula Face SDK service instance to be used.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → FaceApiParams?
Allows you to deserialize object.