FieldType enum
Enum contains identifiers that determine the logical type of text data obtained while reading MRZ, document filling fields, and barcodes.
Values
- UNKNOWN → const FieldType
-
Will be returned if getByValue if a non-existent was passed.
const FieldType(-1) - DOCUMENT_CLASS_CODE → const FieldType
-
Document class code.
const FieldType(0) - ISSUING_STATE_CODE → const FieldType
-
Issuing state code in compliance with 3166-1 standard (ICAO doc 9303).
const FieldType(1) - DOCUMENT_NUMBER → const FieldType
-
Document number.
const FieldType(2) - DATE_OF_EXPIRY → const FieldType
-
Expiry date of the document.
const FieldType(3) - DATE_OF_ISSUE → const FieldType
-
Issue date of the document.
const FieldType(4) - DATE_OF_BIRTH → const FieldType
-
Date of birth.
const FieldType(5) - PLACE_OF_BIRTH → const FieldType
-
Place of birth.
const FieldType(6) - PERSONAL_NUMBER → const FieldType
-
Personal number.
const FieldType(7) - SURNAME → const FieldType
-
Surname.
const FieldType(8) - GIVEN_NAMES → const FieldType
-
Given name(s).
const FieldType(9) - MOTHERS_NAME → const FieldType
-
Mother's name.
const FieldType(10) - NATIONALITY → const FieldType
-
Nationality.
const FieldType(11) - SEX → const FieldType
-
Sex.
const FieldType(12) - HEIGHT → const FieldType
-
Height.
const FieldType(13) - WEIGHT → const FieldType
-
Weight.
const FieldType(14) - EYES_COLOR → const FieldType
-
Eye color.
const FieldType(15) - HAIR_COLOR → const FieldType
-
Hair color.
const FieldType(16) - ADDRESS → const FieldType
-
Address.
const FieldType(17) - DONOR → const FieldType
-
Organ donor indicator.
const FieldType(18) - SOCIAL_SECURITY_NUMBER → const FieldType
-
Social security number.
const FieldType(19) - DL_CLASS → const FieldType
-
Driving licence classification code.
const FieldType(20) - DL_ENDORSED → const FieldType
-
Driving licenсe endorsement code.
const FieldType(21) - DL_RESTRICTION_CODE → const FieldType
-
Driving licence restriction code.
const FieldType(22) - DL_UNDER_21_DATE → const FieldType
-
Date of 21st birthday.
const FieldType(23) - AUTHORITY → const FieldType
-
Issuing authority.
const FieldType(24) - SURNAME_AND_GIVEN_NAMES → const FieldType
-
Surname and given name(s).
const FieldType(25) - NATIONALITY_CODE → const FieldType
-
Nationality code in compliance with ISO3166-1 standard (ICAO doc 9303).
const FieldType(26) - PASSPORT_NUMBER → const FieldType
-
Passport number.
const FieldType(27) - INVITATION_NUMBER → const FieldType
-
Invitation number.
const FieldType(28) - VISA_ID → const FieldType
-
Visa identification number.
const FieldType(29) - VISA_CLASS → const FieldType
-
Visa class.
const FieldType(30) - VISA_SUB_CLASS → const FieldType
-
Visa subclass.
const FieldType(31) - MRZ_STRING_1 → const FieldType
-
Not used.
const FieldType(32) - MRZ_STRING_2 → const FieldType
-
Not used.
const FieldType(33) - MRZ_STRING_3 → const FieldType
-
Not used.
const FieldType(34) - MRZ_TYPE → const FieldType
-
MRZ type (ID-1 – 0, ID-2 – 1, ID-3 – 2).
const FieldType(35) - OPTIONAL_DATA → const FieldType
-
Optional data.
const FieldType(36) - DOCUMENT_CLASS_NAME → const FieldType
-
Document class name.
const FieldType(37) - ISSUING_STATE_NAME → const FieldType
-
Issuing state name.
const FieldType(38) - PLACE_OF_ISSUE → const FieldType
-
Place of issue.
const FieldType(39) - DOCUMENT_NUMBER_CHECKSUM → const FieldType
-
Checksum for document number.
const FieldType(40) - DATE_OF_BIRTH_CHECKSUM → const FieldType
-
Checksum for date of birth.
const FieldType(41) - DATE_OF_EXPIRY_CHECKSUM → const FieldType
-
Checksum for date of expiry.
const FieldType(42) - PERSONAL_NUMBER_CHECKSUM → const FieldType
-
Checksum for personal number.
const FieldType(43) - FINAL_CHECKSUM → const FieldType
-
Final checksum (for the whole MRZ).
const FieldType(44) - PASSPORT_NUMBER_CHECKSUM → const FieldType
-
Checksum for passport number (for visas).
const FieldType(45) - INVITATION_NUMBER_CHECKSUM → const FieldType
-
Checksum for passport number (for visas).
const FieldType(46) - VISA_ID_CHECKSUM → const FieldType
-
Checksum for visa identification number.
const FieldType(47) - SURNAME_AND_GIVEN_NAMES_CHECKSUM → const FieldType
-
Checksum for surname + given name(s).
const FieldType(48) - VISA_VALID_UNTIL_CHECKSUM → const FieldType
-
Checksum for visa expiry date.
const FieldType(49) - OTHER → const FieldType
-
Other information.
const FieldType(50) - MRZ_STRINGS → const FieldType
-
MRZ lines.
const FieldType(51) - NAME_SUFFIX → const FieldType
-
Name suffix.
const FieldType(52) - NAME_PREFIX → const FieldType
-
Name prefix.
const FieldType(53) - DATE_OF_ISSUE_CHECKSUM → const FieldType
-
Checksum for date of issue.
const FieldType(54) - DATE_OF_ISSUE_CHECK_DIGIT → const FieldType
-
Check digit for date of issue.
const FieldType(55) - DOCUMENT_SERIES → const FieldType
-
Document series.
const FieldType(56) - REG_CERT_REG_NUMBER → const FieldType
-
Serial number of registration certificate.
const FieldType(57) - REG_CERT_CAR_MODEL → const FieldType
-
Vehicle model.
const FieldType(58) - REG_CERT_CAR_COLOR → const FieldType
-
Vehicle color.
const FieldType(59) - REG_CERT_BODY_NUMBER → const FieldType
-
Vehicle identification number (VIN).
const FieldType(60) - REG_CERT_CAR_TYPE → const FieldType
-
Vehicle type.
const FieldType(61) - REG_CERT_MAX_WEIGHT → const FieldType
-
Permissible maximum weight.
const FieldType(62) - REG_CERT_WEIGHT → const FieldType
-
Vehicle weight.
const FieldType(63) - ADDRESS_AREA → const FieldType
-
Address (area).
const FieldType(64) - ADDRESS_STATE → const FieldType
-
Address (state).
const FieldType(65) - ADDRESS_BUILDING → const FieldType
-
Address (building number).
const FieldType(66) - ADDRESS_HOUSE → const FieldType
-
Address (house number).
const FieldType(67) - ADDRESS_FLAT → const FieldType
-
Address (flat number).
const FieldType(68) - PLACE_OF_REGISTRATION → const FieldType
-
Place of registration.
const FieldType(69) - DATE_OF_REGISTRATION → const FieldType
-
Date of registration.
const FieldType(70) - RESIDENT_FROM → const FieldType
-
Resident from (date).
const FieldType(71) - RESIDENT_UNTIL → const FieldType
-
Resident until (date).
const FieldType(72) - AUTHORITY_CODE → const FieldType
-
Issuing authority code (for the passport of the Russian Federation).
const FieldType(73) - PLACE_OF_BIRTH_AREA → const FieldType
-
Place of birth (area).
const FieldType(74) - PLACE_OF_BIRTH_STATE_CODE → const FieldType
-
Place of birth (state code).
const FieldType(75) - ADDRESS_STREET → const FieldType
-
Address (street).
const FieldType(76) - ADDRESS_CITY → const FieldType
-
Address (city).
const FieldType(77) - ADDRESS_JURISDICTION_CODE → const FieldType
-
Address (jurisdiction code).
const FieldType(78) - ADDRESS_POSTAL_CODE → const FieldType
-
Address (postal code).
const FieldType(79) - DOCUMENT_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for document number.
const FieldType(80) - DATE_OF_BIRTH_CHECK_DIGIT → const FieldType
-
Check digit for date of birth.
const FieldType(81) - DATE_OF_EXPIRY_CHECK_DIGIT → const FieldType
-
Check digit for document expiry date.
const FieldType(82) - PERSONAL_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for personal number.
const FieldType(83) - FINAL_CHECK_DIGIT → const FieldType
-
Final check digit (for the whole MRZ).
const FieldType(84) - PASSPORT_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for passport number (for visas).
const FieldType(85) - INVITATION_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for invitation number (for visas).
const FieldType(86) - VISA_ID_CHECK_DIGIT → const FieldType
-
Check digit for visa number.
const FieldType(87) - SURNAME_AND_GIVEN_NAMES_CHECK_DIGIT → const FieldType
-
Check digit for surname and given name(s).
const FieldType(88) - VISA_VALID_UNTIL_CHECK_DIGIT → const FieldType
-
Check digit for visa expiry date.
const FieldType(89) - PERMIT_DL_CLASS → const FieldType
-
Permit type.
const FieldType(90) - PERMIT_DATE_OF_EXPIRY → const FieldType
-
Permit expiry date.
const FieldType(91) - PERMIT_IDENTIFIER → const FieldType
-
Permit identifier.
const FieldType(92) - PERMIT_DATE_OF_ISSUE → const FieldType
-
Permit issue date.
const FieldType(93) - PERMIT_RESTRICTION_CODE → const FieldType
-
Driving permit restriction code.
const FieldType(94) - PERMIT_ENDORSED → const FieldType
-
Driving permit endorsement code.
const FieldType(95) - ISSUE_TIMESTAMP → const FieldType
-
A line used for document validation in accordance with the database.
const FieldType(96) - NUMBER_OF_DUPLICATES → const FieldType
-
Number of duplicates.
const FieldType(97) - MEDICAL_INDICATOR_CODES → const FieldType
-
Medical indicator/code.
const FieldType(98) - NON_RESIDENT_INDICATOR → const FieldType
-
Indicator showing that the document holder is a non-resident.
const FieldType(99) - VISA_TYPE → const FieldType
-
Visa type.
const FieldType(100) - VISA_VALID_FROM → const FieldType
-
The earliest date from which the visa is valid.
const FieldType(101) - VISA_VALID_UNTIL → const FieldType
-
The date until which the visa is valid.
const FieldType(102) - DURATION_OF_STAY → const FieldType
-
Duration of stay (in days) granted by the visa.
const FieldType(103) - NUMBER_OF_ENTRIES → const FieldType
-
Number of entries granted by the visa.
const FieldType(104) - DAY → const FieldType
-
Day in the date.
const FieldType(105) - MONTH → const FieldType
-
Month in the date.
const FieldType(106) - YEAR → const FieldType
-
Year in the date.
const FieldType(107) - UNIQUE_CUSTOMER_IDENTIFIER → const FieldType
-
Identification number.
const FieldType(108) - COMMERCIAL_VEHICLE_CODES → const FieldType
-
Commercial vehicle code.
const FieldType(109) - AKA_DATE_OF_BIRTH → const FieldType
-
Also known as (date of birth).
const FieldType(110) - AKA_SOCIAL_SECURITY_NUMBER → const FieldType
-
Also known as (social security number).
const FieldType(111) - AKA_SURNAME → const FieldType
-
Also known as (surname).
const FieldType(112) - AKA_GIVEN_NAMES → const FieldType
-
Also known as (given names).
const FieldType(113) - AKA_NAME_SUFFIX → const FieldType
-
Also known as (suffix name).
const FieldType(114) - AKA_NAME_PREFIX → const FieldType
-
Also known as (prefix name).
const FieldType(115) - MAILING_ADDRESS_STREET → const FieldType
-
Mailing address (street).
const FieldType(116) - MAILING_ADDRESS_CITY → const FieldType
-
Mailing address (city).
const FieldType(117) - MAILING_ADDRESS_JURISDICTION_CODE → const FieldType
-
Mailing address (jurisdiction code).
const FieldType(118) - MAILING_ADDRESS_POSTAL_CODE → const FieldType
-
Mailing address (postal code).
const FieldType(119) - AUDIT_INFORMATION → const FieldType
-
A number which is used for driving licence validation.
const FieldType(120) - INVENTORY_NUMBER → const FieldType
-
Race/ethnicity.
const FieldType(121) - RACE_ETHNICITY → const FieldType
-
Race/ethnicity.
const FieldType(122) - JURISDICTION_VEHICLE_CLASS → const FieldType
-
Jurisdiction vehicle class.
const FieldType(123) - JURISDICTION_ENDORSEMENT_CODE → const FieldType
-
Jurisdiction endorsement code.
const FieldType(124) - JURISDICTION_RESTRICTION_CODE → const FieldType
-
Jurisdiction restriction code.
const FieldType(125) - FAMILY_NAME → const FieldType
-
Surname and (or) given name(s) at birth.
const FieldType(126) - GIVEN_NAMES_RUS → const FieldType
-
Given name(s) (Russian transcription).
const FieldType(127) - VISA_ID_RUS → const FieldType
-
Visa ID (Russian transcription).
const FieldType(128) - FATHERS_NAME → const FieldType
-
Father’s name/patronymic.
const FieldType(129) - FATHERS_NAME_RUS → const FieldType
-
Father’s name/patronymic (Russian transcription).
const FieldType(130) - SURNAME_AND_GIVEN_NAMES_RUS → const FieldType
-
Surname and given name(s) (Russian transcription).
const FieldType(131) - PLACE_OF_BIRTH_RUS → const FieldType
-
Place of birth (Russian transcription).
const FieldType(132) - AUTHORITY_RUS → const FieldType
-
Document issuing authority (Russian transcription).
const FieldType(133) - ISSUING_STATE_CODE_NUMERIC → const FieldType
-
Numeric issuing state code in compliance with ISO 3166-1 standard.
const FieldType(134) - NATIONALITY_CODE_NUMERIC → const FieldType
-
Numeric nationality code in compliance with ISO 3166-1 standard.
const FieldType(135) - ENGINE_POWER → const FieldType
-
Engine power.
const FieldType(136) - ENGINE_VOLUME → const FieldType
-
Engine capacity.
const FieldType(137) - CHASSIS_NUMBER → const FieldType
-
Chassis number.
const FieldType(138) - ENGINE_NUMBER → const FieldType
-
Engine number.
const FieldType(139) - ENGINE_MODEL → const FieldType
-
Engine model.
const FieldType(140) - VEHICLE_CATEGORY → const FieldType
-
Vehicle category.
const FieldType(141) - IDENTITY_CARD_NUMBER → const FieldType
-
Identity card number.
const FieldType(142) - CONTROL_NO → const FieldType
-
Control number.
const FieldType(143) - PARRENTS_GIVEN_NAMES → const FieldType
-
Parents' given names.
const FieldType(144) - SECOND_SURNAME → const FieldType
-
Second surname.
const FieldType(145) - MIDDLE_NAME → const FieldType
-
Second name.
const FieldType(146) - REG_CERT_VIN → const FieldType
-
Vehicle identification number.
const FieldType(147) - REG_CERT_VIN_CHECK_DIGIT → const FieldType
-
Check digit for vehicle identification number.
const FieldType(148) - REG_CERT_VIN_CHECKSUM → const FieldType
-
Checksum for vehicle identification number.
const FieldType(149) - LINE_1_CHECK_DIGIT → const FieldType
-
Check digit for the first MRZ line.
const FieldType(150) - LINE_2_CHECK_DIGIT → const FieldType
-
Check digit for the second MRZ line.
const FieldType(151) - LINE_3_CHECK_DIGIT → const FieldType
-
Check digit for the third MRZ line.
const FieldType(152) - LINE_1_CHECKSUM → const FieldType
-
Checksum for the first MRZ line.
const FieldType(153) - LINE_2_CHECKSUM → const FieldType
-
Checksum for the second MRZ line.
const FieldType(154) - LINE_3_CHECKSUM → const FieldType
-
Checksum for the third MRZ line.
const FieldType(155) - REG_CERT_REG_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for vehicle registration number.
const FieldType(156) - REG_CERT_REG_NUMBER_CHECKSUM → const FieldType
-
Check sum for vehicle registration number.
const FieldType(157) - REG_CERT_VEHICLE_ITS_CODE → const FieldType
-
Vehicle code according to ITS (IntelligentTransportation Systems).
const FieldType(158) - CARD_ACCESS_NUMBER → const FieldType
-
Access number for RFID chip.
const FieldType(159) - MARITAL_STATUS → const FieldType
-
Marital status.
const FieldType(160) - COMPANY_NAME → const FieldType
-
Company name.
const FieldType(161) - SPECIAL_NOTES → const FieldType
-
Special notes.
const FieldType(162) - SURNAME_OF_SPOSE → const FieldType
-
Surname of spouse.
const FieldType(163) - TRACKING_NUMBER → const FieldType
-
Number for checking document status.
const FieldType(164) - BOOKLET_NUMBER → const FieldType
-
Booklet number.
const FieldType(165) - CHILDREN → const FieldType
-
Children.
const FieldType(166) - COPY → const FieldType
-
Copy number.
const FieldType(167) - SERIAL_NUMBER → const FieldType
-
Serial number.
const FieldType(168) - DOSSIER_NUMBER → const FieldType
-
Dossier number.
const FieldType(169) - AKA_SURNAME_AND_GIVEN_NAMES → const FieldType
-
Also known as (surname and given names).
const FieldType(170) - TERRITORIAL_VALIDITY → const FieldType
-
Territorial validity.
const FieldType(171) - MRZ_STRINGS_WITH_CORRECT_CHECK_SUMS → const FieldType
-
MRZ with correct checksums.
const FieldType(172) - DL_CDL_RESTRICTION_CODE → const FieldType
-
Commercial driving license restriction code.
const FieldType(173) - DL_UNDER_18_DATE → const FieldType
-
Date of 18th birthday.
const FieldType(174) - DL_RECORD_CREATED → const FieldType
-
Date of record creation.
const FieldType(175) - DL_DUPLICATE_DATE → const FieldType
-
Date of duplicate creation.
const FieldType(176) - DL_ISS_TYPE → const FieldType
-
Type of issued driving license.
const FieldType(177) - MILITARY_BOOK_NUMBER → const FieldType
-
Military card number.
const FieldType(178) - DESTINATION → const FieldType
-
Destination.
const FieldType(179) - BLOOD_GROUP → const FieldType
-
Blood group.
const FieldType(180) - SEQUENCE_NUMBER → const FieldType
-
Sequence number.
const FieldType(181) - REG_CERT_BODY_TYPE → const FieldType
-
Car body type.
const FieldType(182) - REG_CERT_CAR_MARK → const FieldType
-
Car make.
const FieldType(183) - TRANSACTION_NUMBER → const FieldType
-
Transaction number.
const FieldType(184) - AGE → const FieldType
-
Age.
const FieldType(185) - FOLIO_NUMBER → const FieldType
-
Folio number.
const FieldType(186) - VOTER_KEY → const FieldType
-
Voter's identification number.
const FieldType(187) - ADDRESS_MUNICIPALITY → const FieldType
-
Address (municipality).
const FieldType(188) - ADDRESS_LOCATION → const FieldType
-
Address (location).
const FieldType(189) - SECTION → const FieldType
-
Section/sector.
const FieldType(190) - OCR_NUMBER → const FieldType
-
OCR number.
const FieldType(191) - FEDERAL_ELECTIONS → const FieldType
-
Federal elections.
const FieldType(192) - REFERENCE_NUMBER → const FieldType
-
Unique number.
const FieldType(193) - OPTIONAL_DATA_CHECKSUM → const FieldType
-
Checksum for optional data.
const FieldType(194) - OPTIONAL_DATA_CHECK_DIGIT → const FieldType
-
Check digit for optional data.
const FieldType(195) - VISA_NUMBER → const FieldType
-
Visa number.
const FieldType(196) - VISA_NUMBER_CHECKSUM → const FieldType
-
Checksum for visa.
const FieldType(197) - VISA_NUMBER_CHECK_DIGIT → const FieldType
-
Checkdigit for visa.
const FieldType(198) - VOTER → const FieldType
-
Voter.
const FieldType(199) - PREVIOUS_TYPE → const FieldType
-
Type/number of the previous document.
const FieldType(200) - FIELD_FROM_MRZ → const FieldType
-
Reserved for internal use.
const FieldType(220) - CURRENT_DATE → const FieldType
-
Reserved for internal use.
const FieldType(221) - STATUS_DATE_OF_EXPIRY → const FieldType
-
Status expiry date.
const FieldType(251) - BANKNOTE_NUMBER → const FieldType
-
Banknote number.
const FieldType(252) - CSC_CODE → const FieldType
-
Customer Service Centre code.
const FieldType(253) - ARTISTIC_NAME → const FieldType
-
Pseudonym.
const FieldType(254) - ACADEMIC_TITLE → const FieldType
-
Academic title.
const FieldType(255) - ADDRESS_COUNTRY → const FieldType
-
Address (country).
const FieldType(256) - ADDRESS_ZIPCODE → const FieldType
-
Address (zip code).
const FieldType(257) - E_ID_RESIDENCE_PERMIT_1 → const FieldType
-
Data on permanent residence permit 1(eID field).
const FieldType(258) - E_ID_RESIDENCE_PERMIT_2 → const FieldType
-
Data on permanent residence permit 2(eID field).
const FieldType(259) - E_ID_PLACE_OF_BIRTH_STREET → const FieldType
-
Place of birth: street (eID field).
const FieldType(260) - E_ID_PLACE_OF_BIRTH_CITY → const FieldType
-
Place of birth: city (eID field).
const FieldType(261) - E_ID_PLACE_OF_BIRTH_STATE → const FieldType
-
Place of birth: state (eID field).
const FieldType(262) - E_ID_PLACE_OF_BIRTH_COUNTRY → const FieldType
-
Place of birth: country (eID field).
const FieldType(263) - E_ID_PLACE_OF_BIRTH_ZIPCODE → const FieldType
-
Place of birth: zip code (eID field).
const FieldType(264) - CDL_CLASS → const FieldType
-
Commercial driving license class.
const FieldType(265) - DL_UNDER_19_DATE → const FieldType
-
Date of 19th birthday.
const FieldType(266) - WEIGHT_POUNDS → const FieldType
-
Weight (pounds).
const FieldType(267) - LIMITED_DURATION_DOCUMENT_INDICATOR → const FieldType
-
Indicator of document limited duration.
const FieldType(268) - ENDORSEMENT_EXPIRATION_DATE → const FieldType
-
Endorsement expiry date.
const FieldType(269) - REVISION_DATE → const FieldType
-
Date of revision.
const FieldType(270) - COMPLIANCE_TYPE → const FieldType
-
Type of compliance.
const FieldType(271) - FAMILY_NAME_TRUNCATION → const FieldType
-
Family name truncation.
const FieldType(272) - FIRST_NAME_TRUNCATION → const FieldType
-
First name truncation.
const FieldType(273) - MIDDLE_NAME_TRUNCATION → const FieldType
-
Middle name truncation.
const FieldType(274) - EXAM_DATE → const FieldType
-
Examination date.
const FieldType(275) - ORGANIZATION → const FieldType
-
Organization.
const FieldType(276) - DEPARTMENT → const FieldType
-
Department.
const FieldType(277) - PAY_GRADE → const FieldType
-
Pay grade.
const FieldType(278) - RANK → const FieldType
-
Rank/status/title.
const FieldType(279) - BENEFITS_NUMBER → const FieldType
-
Number that relates to benefit eligibility.
const FieldType(280) - SPONSOR_SERVICE → const FieldType
-
Sponsor's service.
const FieldType(281) - SPONSOR_STATUS → const FieldType
-
Sponsor's status.
const FieldType(282) - SPONSOR → const FieldType
-
Sponsor.
const FieldType(283) - RELATIONSHIP → const FieldType
-
Relationship.
const FieldType(284) - USCIS → const FieldType
-
Alien registration number issued by the U.S. Citizenship and Immigration Service.
const FieldType(285) - CATEGORY → const FieldType
-
Category.
const FieldType(286) - CONDITIONS → const FieldType
-
Conditions.
const FieldType(287) - IDENTIFIER → const FieldType
-
Identifier.
const FieldType(288) - CONFIGURATION → const FieldType
-
Configuration.
const FieldType(289) - DISCRETIONARY_DATA → const FieldType
-
Discretionary data.
const FieldType(290) - LINE_1_OPTIONAL_DATA → const FieldType
-
Optional data from MRZ Line 1.
const FieldType(291) - LINE_2_OPTIONAL_DATA → const FieldType
-
Optional data from MRZ Line 2.
const FieldType(292) - LINE_3_OPTIONAL_DATA → const FieldType
-
Optional data from MRZ Line 3.
const FieldType(293) - EQV_CODE → const FieldType
-
Equivalence value (security code).
const FieldType(294) - ALT_CODE → const FieldType
-
ALT сode.
const FieldType(295) - BINARY_CODE → const FieldType
-
Binary сode.
const FieldType(296) - PSEUDO_CODE → const FieldType
-
Pseudo-code.
const FieldType(297) - FEE → const FieldType
-
Fee.
const FieldType(298) - STAMP_NUMBER → const FieldType
-
Stamp number.
const FieldType(299) - SBH_SECURITYOPTIONS → const FieldType
-
Parameters of biometric data protection.
const FieldType(300) - SBH_INTEGRITYOPTIONS → const FieldType
-
Parameters of biometric data integrity.
const FieldType(301) - DATE_OF_CREATION → const FieldType
-
Date of creation of biometric data record.
const FieldType(302) - VALIDITY_PERIOD → const FieldType
-
Term of validity of biometric data record.
const FieldType(303) - PATRON_HEADER_VERSION → const FieldType
-
Version of header of biometric data format owner.
const FieldType(304) - BDB_TYPE → const FieldType
-
Type of biometric data record.
const FieldType(305) - BIOMETRIC_TYPE → const FieldType
-
Type of biometric data.
const FieldType(306) - BIOMETRIC_SUBTYPE → const FieldType
-
Subtype of biometric data.
const FieldType(307) - BIOMETRIC_PRODUCTID → const FieldType
-
Identifier of biometric data.
const FieldType(308) - BIOMETRIC_FORMAT_OWNER → const FieldType
-
Identifier of biometric data format owner.
const FieldType(309) - BIOMETRIC_FORMAT_TYPE → const FieldType
-
Biometric data format.
const FieldType(310) - PHONE → const FieldType
-
DO's phone number.
const FieldType(311) - PROFESSION → const FieldType
-
DO's profession.
const FieldType(312) - TITLE → const FieldType
-
DO's title.
const FieldType(313) - PERSONAL_SUMMARY → const FieldType
-
DO's personal summary data.
const FieldType(314) - OTHER_VALID_ID → const FieldType
-
Other valid identifier.
const FieldType(315) - CUSTODY_INFO → const FieldType
-
Custody information.
const FieldType(316) - OTHER_NAME → const FieldType
-
Other name.
const FieldType(317) - OBSERVATIONS → const FieldType
-
Observations.
const FieldType(318) - TAX → const FieldType
-
Tax information.
const FieldType(319) - DATE_OF_PERSONALIZATION → const FieldType
-
Date of document personalization.
const FieldType(320) - PERSONALIZATION_SN → const FieldType
-
Serial number of personalization.
const FieldType(321) - OTHERPERSON_NAME → const FieldType
-
Other person's name.
const FieldType(322) - PERSONTONOTIFY_DATE_OF_RECORD → const FieldType
-
Date of record entry on persons to notify in case of emergency.
const FieldType(323) - PERSONTONOTIFY_NAME → const FieldType
-
Name of person to notify in case of emergency.
const FieldType(324) - PERSONTONOTIFY_PHONE → const FieldType
-
Phone number of person to notify in case of emergency.
const FieldType(325) - PERSONTONOTIFY_ADDRESS → const FieldType
-
Address of person to notify in case of emergency.
const FieldType(326) - DS_CERTIFICATE_ISSUER → const FieldType
-
Textual information about the DS-certificate issuer.
const FieldType(327) - DS_CERTIFICATE_SUBJECT → const FieldType
-
Textual information about the document issuer.
const FieldType(328) - DS_CERTIFICATE_VALIDFROM → const FieldType
-
Start date of the DS-certificate validity.
const FieldType(329) - DS_CERTIFICATE_VALIDTO → const FieldType
-
Expiration date of the DS-certificate.
const FieldType(330) - VRC_DATAOBJECT_ENTRY → const FieldType
-
Vehicle category/restrictions/conditions from DG1 data group of eDL application.
const FieldType(331) - TYPE_APPROVAL_NUMBER → const FieldType
-
Type approval number.
const FieldType(332) - ADMINISTRATIVE_NUMBER → const FieldType
-
Administrative number.
const FieldType(333) - DOCUMENT_DISCRIMINATOR → const FieldType
-
Document discriminator.
const FieldType(334) - DATA_DISCRIMINATOR → const FieldType
-
Data discriminator.
const FieldType(335) - ISO_ISSUER_ID_NUMBER → const FieldType
-
ISO issuer ID number.
const FieldType(336) - DTC_VERSION → const FieldType
-
const FieldType(337) - DTC_ID → const FieldType
-
const FieldType(338) - DTC_DATE_OF_EXPIRY → const FieldType
-
const FieldType(339) - GNIB_NUMBER → const FieldType
-
Registration number issued by GardaNational Immigration Bureau.
const FieldType(340) - DEPT_NUMBER → const FieldType
-
Department number.
const FieldType(341) - TELEX_CODE → const FieldType
-
Telegraph code.
const FieldType(342) - ALLERGIES → const FieldType
-
Allergies.
const FieldType(343) - SP_CODE → const FieldType
-
Sp. code.
const FieldType(344) - COURT_CODE → const FieldType
-
Code of restriction imposed by court.
const FieldType(345) - CTY → const FieldType
-
County code.
const FieldType(346) - SPONSOR_SSN → const FieldType
-
Sponsor's social security number.
const FieldType(347) - DO_D_NUMBER → const FieldType
-
Department of Defense identification number.
const FieldType(348) - MC_NOVICE_DATE → const FieldType
-
Expiry date of Motorcycle status.
const FieldType(349) - DUF_NUMBER → const FieldType
-
DUF Number (a number that is assigned to everyone who applies for residence inNorway).
const FieldType(350) - AGY → const FieldType
-
Code of Philippine Land TransportationOffice Agency.
const FieldType(351) - PNR_CODE → const FieldType
-
Passenger name record (reservation code).
const FieldType(352) - FROM_AIRPORT_CODE → const FieldType
-
Code of the airport of departure.
const FieldType(353) - TO_AIRPORT_CODE → const FieldType
-
Code of the airport of arrival.
const FieldType(354) - FLIGHT_NUMBER → const FieldType
-
Flight number.
const FieldType(355) - DATE_OF_FLIGHT → const FieldType
-
Date of flight.
const FieldType(356) - SEAT_NUMBER → const FieldType
-
Seat number.
const FieldType(357) - DATE_OF_ISSUE_BOARDING_PASS → const FieldType
-
Date of boarding pass issue.
const FieldType(358) - CCW_UNTIL → const FieldType
-
Expiration date of Concealed CarryWeapon Permit.
const FieldType(359) - REFERENCE_NUMBER_CHECKSUM → const FieldType
-
Checksum for reference number.
const FieldType(360) - REFERENCE_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for reference number.
const FieldType(361) - ROOM_NUMBER → const FieldType
-
Room number.
const FieldType(362) - RELIGION → const FieldType
-
Religion.
const FieldType(363) - REMAINDER_TERM → const FieldType
-
Months to expire.
const FieldType(364) - ELECTRONIC_TICKET_INDICATOR → const FieldType
-
Electronic ticket indicator.
const FieldType(365) - COMPARTMENT_CODE → const FieldType
-
Compartment сode.
const FieldType(366) - CHECK_IN_SEQUENCE_NUMBER → const FieldType
-
Check-in sequence number on a boarding pass.
const FieldType(367) - AIRLINE_DESIGNATOR_OF_BOARDING_PASS_ISSUER → const FieldType
-
Code of the airline which issued the boarding pass.
const FieldType(368) - AIRLINE_NUMERIC_CODE → const FieldType
-
Numeric airline code.
const FieldType(369) - TICKET_NUMBER → const FieldType
-
Ticket number.
const FieldType(370) - FREQUENT_FLYER_AIRLINE_DESIGNATOR → const FieldType
-
Frequent flyer indicator.
const FieldType(371) - FREQUENT_FLYER_NUMBER → const FieldType
-
Frequent flyer number.
const FieldType(372) - FREE_BAGGAGE_ALLOWANCE → const FieldType
-
Free baggage allowance.
const FieldType(373) - PDF_417_CODEC → const FieldType
-
Codec for PDF417.
const FieldType(374) - IDENTITY_CARD_NUMBER_CHECKSUM → const FieldType
-
Checksum for identity card number.
const FieldType(375) - IDENTITY_CARD_NUMBER_CHECK_DIGIT → const FieldType
-
Check digit for identity card number.
const FieldType(376) - VETERAN → const FieldType
-
Veteran.
const FieldType(377) - DL_CLASS_CODE_A_1_FROM → const FieldType
-
DL class code A1 valid from.
const FieldType(378) - DL_CLASS_CODE_A_1_TO → const FieldType
-
DL class code A1 valid to.
const FieldType(379) - DL_CLASS_CODE_A_1_NOTES → const FieldType
-
DL class code A1 valid notes.
const FieldType(380) - DL_CLASS_CODE_A_FROM → const FieldType
-
DL class code A1 valid from.
const FieldType(381) - DL_CLASS_CODE_A_TO → const FieldType
-
DL class code A1 valid to.
const FieldType(382) - DL_CLASS_CODE_A_NOTES → const FieldType
-
DL class code A1 valid notes.
const FieldType(383) - DL_CLASS_CODE_B_FROM → const FieldType
-
DL class code B valid from.
const FieldType(384) - DL_CLASS_CODE_B_TO → const FieldType
-
DL class code B valid to.
const FieldType(385) - DL_CLASS_CODE_B_NOTES → const FieldType
-
DL class code B valid notes.
const FieldType(386) - DL_CLASS_CODE_C_1_FROM → const FieldType
-
DL class code C1 valid from.
const FieldType(387) - DL_CLASS_CODE_C_1_TO → const FieldType
-
DL class code C1 valid to.
const FieldType(388) - DL_CLASS_CODE_C_1_NOTES → const FieldType
-
DL class code C1 valid notes.
const FieldType(389) - DL_CLASS_CODE_C_FROM → const FieldType
-
DL class code C valid from.
const FieldType(390) - DL_CLASS_CODE_C_TO → const FieldType
-
DL class code C valid to.
const FieldType(391) - DL_CLASS_CODE_C_NOTES → const FieldType
-
DL class code C valid notes.
const FieldType(392) - DL_CLASS_CODE_D_1_FROM → const FieldType
-
DL class code D1 valid from.
const FieldType(393) - DL_CLASS_CODE_D_1_TO → const FieldType
-
DL class code D1 valid to.
const FieldType(394) - DL_CLASS_CODE_D_1_NOTES → const FieldType
-
DL class code D1 valid notes.
const FieldType(395) - DL_CLASS_CODE_D_FROM → const FieldType
-
DL class code D valid from.
const FieldType(396) - DL_CLASS_CODE_D_TO → const FieldType
-
DL class code D valid to.
const FieldType(397) - DL_CLASS_CODE_D_NOTES → const FieldType
-
DL class code D valid notes.
const FieldType(398) - DL_CLASS_CODE_BE_FROM → const FieldType
-
DL class code BE valid from.
const FieldType(399) - DL_CLASS_CODE_BE_TO → const FieldType
-
DL class code BE valid to.
const FieldType(400) - DL_CLASS_CODE_BE_NOTES → const FieldType
-
DL class code BE valid notes.
const FieldType(401) - DL_CLASS_CODE_C_1_E_FROM → const FieldType
-
DL class code C1E valid from.
const FieldType(402) - DL_CLASS_CODE_C_1_E_TO → const FieldType
-
DL class code C1E valid to.
const FieldType(403) - DL_CLASS_CODE_C_1_E_NOTES → const FieldType
-
DL class code C1E valid notes.
const FieldType(404) - DL_CLASS_CODE_CE_FROM → const FieldType
-
DL class code CE valid from.
const FieldType(405) - DL_CLASS_CODE_CE_TO → const FieldType
-
DL class code CE valid to.
const FieldType(406) - DL_CLASS_CODE_CE_NOTES → const FieldType
-
DL class code CE valid notes.
const FieldType(407) - DL_CLASS_CODE_D_1_E_FROM → const FieldType
-
DL class code D1E valid from.
const FieldType(408) - DL_CLASS_CODE_D_1_E_TO → const FieldType
-
DL class code D1E valid to.
const FieldType(409) - DL_CLASS_CODE_D_1_E_NOTES → const FieldType
-
DL class code D1E valid notes.
const FieldType(410) - DL_CLASS_CODE_DE_FROM → const FieldType
-
DL class code DE valid from.
const FieldType(411) - DL_CLASS_CODE_DE_TO → const FieldType
-
DL class code DE valid to.
const FieldType(412) - DL_CLASS_CODE_DE_NOTES → const FieldType
-
DL class code DE valid notes.
const FieldType(413) - DL_CLASS_CODE_M_FROM → const FieldType
-
DL class code M valid from.
const FieldType(414) - DL_CLASS_CODE_M_TO → const FieldType
-
DL class code M valid to.
const FieldType(415) - DL_CLASS_CODE_M_NOTES → const FieldType
-
DL class code M valid notes.
const FieldType(416) - DL_CLASS_CODE_L_FROM → const FieldType
-
DL class code L valid from.
const FieldType(417) - DL_CLASS_CODE_L_TO → const FieldType
-
DL class code L valid to.
const FieldType(418) - DL_CLASS_CODE_L_NOTES → const FieldType
-
DL class code L valid notes.
const FieldType(419) - DL_CLASS_CODE_T_FROM → const FieldType
-
DL class code T valid from.
const FieldType(420) - DL_CLASS_CODE_T_TO → const FieldType
-
DL class code T valid to.
const FieldType(421) - DL_CLASS_CODE_T_NOTES → const FieldType
-
DL class code T valid notes.
const FieldType(422) - DL_CLASS_CODE_AM_FROM → const FieldType
-
DL class code AM valid from.
const FieldType(423) - DL_CLASS_CODE_AM_TO → const FieldType
-
DL class code AM valid to.
const FieldType(424) - DL_CLASS_CODE_AM_NOTES → const FieldType
-
DL class code AM valid notes.
const FieldType(425) - DL_CLASS_CODE_A_2_FROM → const FieldType
-
DL class code A2 valid from.
const FieldType(426) - DL_CLASS_CODE_A_2_TO → const FieldType
-
DL class code A2 valid to.
const FieldType(427) - DL_CLASS_CODE_A_2_NOTES → const FieldType
-
DL class code A2 valid notes.
const FieldType(428) - DL_CLASS_CODE_B_1_FROM → const FieldType
-
DL class code B1 valid from.
const FieldType(429) - DL_CLASS_CODE_B_1_TO → const FieldType
-
DL class code B1 valid to.
const FieldType(430) - DL_CLASS_CODE_B_1_NOTES → const FieldType
-
DL class code B1 valid notes.
const FieldType(431) - SURNAME_AT_BIRTH → const FieldType
-
Surname at birth.
const FieldType(432) - CIVIL_STATUS → const FieldType
-
Civil status.
const FieldType(433) - NUMBER_OF_SEATS → const FieldType
-
Number of seats.
const FieldType(434) - NUMBER_OF_STANDING_PLACES → const FieldType
-
Number of standing places.
const FieldType(435) - MAX_SPEED → const FieldType
-
Maximum speed.
const FieldType(436) - FUEL_TYPE → const FieldType
-
Fuel type.
const FieldType(437) - EC_ENVIRONMENTAL_TYPE → const FieldType
-
Vehicle environmental type.
const FieldType(438) - POWER_WEIGHT_RATIO → const FieldType
-
Power–to–weight ratio.
const FieldType(439) - MAX_MASS_OF_TRAILER_BRAKED → const FieldType
-
Maximum weight of the trailer without brakes.
const FieldType(440) - MAX_MASS_OF_TRAILER_UNBRAKED → const FieldType
-
Maximum weight of the trailer without brakes.
const FieldType(441) - TRANSMISSION_TYPE → const FieldType
-
Transmission type.
const FieldType(442) - TRAILER_HITCH → const FieldType
-
Trailer hitch.
const FieldType(443) - ACCOMPANIED_BY → const FieldType
-
Accompanying person.
const FieldType(444) - POLICE_DISTRICT → const FieldType
-
Police district.
const FieldType(445) - FIRST_ISSUE_DATE → const FieldType
-
Date of first issue.
const FieldType(446) - PAYLOAD_CAPACITY → const FieldType
-
Payload capacity.
const FieldType(447) - NUMBER_OF_AXELS → const FieldType
-
Number of axels.
const FieldType(448) - PERMISSIBLE_AXLE_LOAD → const FieldType
-
Permissible axle load.
const FieldType(449) - PRECINCT → const FieldType
-
Precinct.
const FieldType(450) - INVITED_BY → const FieldType
-
Invited by.
const FieldType(451) - PURPOSE_OF_ENTRY → const FieldType
-
Purpose of entry.
const FieldType(452) - SKIN_COLOR → const FieldType
-
Skin color.
const FieldType(453) - COMPLEXION → const FieldType
-
Complexion.
const FieldType(454) - AIRPORT_FROM → const FieldType
-
Airport of departure.
const FieldType(455) - AIRPORT_TO → const FieldType
-
Airport of arrival.
const FieldType(456) - AIRLINE_NAME → const FieldType
-
Airline name.
const FieldType(457) - AIRLINE_NAME_FREQUENT_FLYER → const FieldType
-
A loyalty program offered by the airline to its customers who fly frequently.
const FieldType(458) - LICENSE_NUMBER → const FieldType
-
Licenсe number.
const FieldType(459) - IN_TANKS → const FieldType
-
In tanks.
const FieldType(460) - EXEPT_IN_TANKS → const FieldType
-
Except in tanks.
const FieldType(461) - FAST_TRACK → const FieldType
-
Passenger using the Fast Track service in the airport.
const FieldType(462) - OWNER → const FieldType
-
Owner.
const FieldType(463) - MRZ_STRINGS_ICAO_RFID → const FieldType
-
MRZ strings from ICAO RFID.
const FieldType(464) - NUMBER_OF_CARD_ISSUANCE → const FieldType
-
The number of times a card with this number has been issued.
const FieldType(465) - NUMBER_OF_CARD_ISSUANCE_CHECKSUM → const FieldType
-
Number of card issuance checksum.
const FieldType(466) - NUMBER_OF_CARD_ISSUANCE_CHECK_DIGIT → const FieldType
-
Number of card issuance check digit.
const FieldType(467) - CENTURY_DATE_OF_BIRTH → const FieldType
-
Century of birth.
const FieldType(468) - DL_CLASSCODE_A3_FROM → const FieldType
-
DL class code A3 valid from.
const FieldType(469) - DL_CLASSCODE_A3_TO → const FieldType
-
DL class code A3 valid to.
const FieldType(470) - DL_CLASSCODE_A3_NOTES → const FieldType
-
DL class code A3 valid notes.
const FieldType(471) - DL_CLASSCODE_C2_FROM → const FieldType
-
DL class code C2 valid from.
const FieldType(472) - DL_CLASSCODE_C2_TO → const FieldType
-
DL class code C2 valid to.
const FieldType(473) - DL_CLASSCODE_C2_NOTES → const FieldType
-
DL class code C2 valid notes.
const FieldType(474) - DL_CLASSCODE_B2_FROM → const FieldType
-
DL class code B2 valid from.
const FieldType(475) - DL_CLASSCODE_B2_TO → const FieldType
-
DL class code B2 valid to.
const FieldType(476) - DL_CLASSCODE_B2_NOTES → const FieldType
-
DL class code B2 valid notes.
const FieldType(477) - DL_CLASSCODE_D2_FROM → const FieldType
-
DL class code D2 valid from.
const FieldType(478) - DL_CLASSCODE_D2_TO → const FieldType
-
DL class code B2 valid to.
const FieldType(479) - DL_CLASSCODE_D2_NOTES → const FieldType
-
DL class code B2 valid notes.
const FieldType(480) - DL_CLASSCODE_B2E_FROM → const FieldType
-
DL class code B2E valid from.
const FieldType(481) - DL_CLASSCODE_B2E_TO → const FieldType
-
DL class code B2E valid to.
const FieldType(482) - DL_CLASSCODE_B2E_NOTES → const FieldType
-
DL class code B2E valid notes.
const FieldType(483) - DL_CLASSCODE_G_FROM → const FieldType
-
DL class code G valid from.
const FieldType(484) - DL_CLASSCODE_G_TO → const FieldType
-
DL class code G valid to.
const FieldType(485) - DL_CLASSCODE_G_NOTES → const FieldType
-
DL class code G valid notes.
const FieldType(486) - DL_CLASSCODE_J_FROM → const FieldType
-
DL class code J valid from.
const FieldType(487) - DL_CLASSCODE_J_TO → const FieldType
-
DL class code J valid to.
const FieldType(488) - DL_CLASSCODE_J_NOTES → const FieldType
-
DL class code J valid notes.
const FieldType(489) - DL_CLASSCODE_LC_FROM → const FieldType
-
DL class code LC valid from.
const FieldType(490) - DL_CLASSCODE_LC_TO → const FieldType
-
DL class code LC valid to.
const FieldType(491) - DLC_LASSCODE_LC_NOTES → const FieldType
-
DL class code LC valid notes.
const FieldType(492) - BANKCARDNUMBER → const FieldType
-
Bank card number.
const FieldType(493) - BANKCARDVALIDTHRU → const FieldType
-
Bank card validity.
const FieldType(494) - TAX_NUMBER → const FieldType
-
Tax number.
const FieldType(495) - HEALTH_NUMBER → const FieldType
-
Health insurance number.
const FieldType(496) - GRANDFATHERNAME → const FieldType
-
Grandfather's name.
const FieldType(497) - SELECTEE_INDICATOR → const FieldType
-
Selectee indicator.
const FieldType(498) - MOTHER_SURNAME → const FieldType
-
Mother's surname.
const FieldType(499) - MOTHER_GIVENNAME → const FieldType
-
Mother's given name.
const FieldType(500) - FATHER_SURNAME → const FieldType
-
Father's surname.
const FieldType(501) - FATHER_GIVENNAME → const FieldType
-
Father's given name.
const FieldType(502) - MOTHER_DATEOFBIRTH → const FieldType
-
Mother's date of birth.
const FieldType(503) - FATHER_DATEOFBIRTH → const FieldType
-
Father's date of birth.
const FieldType(504) - MOTHER_PERSONALNUMBER → const FieldType
-
Mother's personal number.
const FieldType(505) - FATHER_PERSONALNUMBER → const FieldType
-
Father's personal number.
const FieldType(506) - MOTHER_PLACEOFBIRTH → const FieldType
-
Mother's place of birth.
const FieldType(507) - FATHER_PLACEOFBIRTH → const FieldType
-
Father's place of birth.
const FieldType(508) - MOTHER_COUNTRYOFBIRTH → const FieldType
-
Mother's country of birth.
const FieldType(509) - FATHER_COUNTRYOFBIRTH → const FieldType
-
Father's country of birth.
const FieldType(510) - DATE_FIRST_RENEWAL → const FieldType
-
Date of first renewal.
const FieldType(511) - DATE_SECOND_RENEWAL → const FieldType
-
Date of second renewal.
const FieldType(512) - PLACE_OF_EXAMINATION → const FieldType
-
Place of examination.
const FieldType(513) - APPLICATION_NUMBER → const FieldType
-
Application number.
const FieldType(514) - VOUCHER_NUMBER → const FieldType
-
Voucher number.
const FieldType(515) - AUTHORIZATION_NUMBER → const FieldType
-
Authorization number.
const FieldType(516) - FACULTY → const FieldType
-
Faculty.
const FieldType(517) - FORM_OF_EDUCATION → const FieldType
-
Form of education.
const FieldType(518) - DNI_NUMBER → const FieldType
-
DNI number.
const FieldType(519) - RETIREMENT_NUMBER → const FieldType
-
Retirement number.
const FieldType(520) - PROFESSIONAL_ID_NUMBER → const FieldType
-
Professional Id number.
const FieldType(521) - AGE_AT_ISSUE → const FieldType
-
Age at issue.
const FieldType(522) - YEARS_SINCE_ISSUE → const FieldType
-
Years since issue.
const FieldType(523) - DLCLASSCODE_BTP_FROM → const FieldType
-
DL class code BTP valid from.
const FieldType(524) - DLCLASSCODE_BTP_NOTES → const FieldType
-
DL class code BTP valid notes.
const FieldType(525) - DLCLASSCODE_BTP_TO → const FieldType
-
DL class code BTP valid to.
const FieldType(526) - DLCLASSCODE_C3_FROM → const FieldType
-
DL class code C3 valid from.
const FieldType(527) - DLCLASSCODE_C3_NOTES → const FieldType
-
DL class code C3 valid notes.
const FieldType(528) - DLCLASSCODE_C3_TO → const FieldType
-
DL class code C3 valid to.
const FieldType(529) - DLCLASSCODE_E_FROM → const FieldType
-
DL class code E valid from.
const FieldType(530) - DLCLASSCODE_E_NOTES → const FieldType
-
DL class code E valid notes.
const FieldType(531) - DLCLASSCODE_E_TO → const FieldType
-
DL class code E valid to.
const FieldType(532) - DLCLASSCODE_F_FROM → const FieldType
-
DL class code F valid from.
const FieldType(533) - DLCLASSCODE_F_NOTES → const FieldType
-
DL class code F valid notes.
const FieldType(534) - DLCLASSCODE_F_TO → const FieldType
-
DL class code F valid to.
const FieldType(535) - DLCLASSCODE_FA_FROM → const FieldType
-
DL class code FA valid from.
const FieldType(536) - DLCLASSCODE_FA_NOTES → const FieldType
-
DL class code FA valid notes.
const FieldType(537) - DLCLASSCODE_FA_TO → const FieldType
-
DL class code FA valid to.
const FieldType(538) - DLCLASSCODE_FA1_FROM → const FieldType
-
DL class code FA1 valid from.
const FieldType(539) - DLCLASSCODE_FA1_NOTES → const FieldType
-
DL class code FA1 valid notes.
const FieldType(540) - DLCLASSCODE_FA1_TO → const FieldType
-
DL class code FA1 valid to.
const FieldType(541) - DLCLASSCODE_FB_FROM → const FieldType
-
DL class code FB valid from.
const FieldType(542) - DLCLASSCODE_FB_NOTES → const FieldType
-
DL class code FB valid notes.
const FieldType(543) - DLCLASSCODE_FB_TO → const FieldType
-
DL class code FB valid to.
const FieldType(544) - DLCLASSCODE_G1_FROM → const FieldType
-
DL class code G1 valid from.
const FieldType(545) - DLCLASSCODE_G1_NOTES → const FieldType
-
DL class code G1 valid notes.
const FieldType(546) - DLCLASSCODE_G1_TO → const FieldType
-
DL class code G1 valid to.
const FieldType(547) - DLCLASSCODE_H_FROM → const FieldType
-
DL class code H valid from.
const FieldType(548) - DLCLASSCODE_H_NOTES → const FieldType
-
DL class code H valid notes.
const FieldType(549) - DLCLASSCODE_H_TO → const FieldType
-
DL class code H valid to.
const FieldType(550) - DLCLASSCODE_I_FROM → const FieldType
-
DL class code I valid from.
const FieldType(551) - DLCLASSCODE_I_NOTES → const FieldType
-
DL class code I valid notes.
const FieldType(552) - DLCLASSCODE_I_TO → const FieldType
-
DL class code I valid to.
const FieldType(553) - DLCLASSCODE_K_FROM → const FieldType
-
DL class code K valid from.
const FieldType(554) - DLCLASSCODE_K_NOTES → const FieldType
-
DL class code K valid notes.
const FieldType(555) - DLCLASSCODE_K_TO → const FieldType
-
DL class code K valid to.
const FieldType(556) - DLCLASSCODE_LK_FROM → const FieldType
-
DL class code LK valid from.
const FieldType(557) - DLCLASSCODE_LK_NOTES → const FieldType
-
DL class code LK valid notes.
const FieldType(558) - DLCLASSCODE_LK_TO → const FieldType
-
DL class code LK valid to.
const FieldType(559) - DLCLASSCODE_N_FROM → const FieldType
-
DL class code N valid from.
const FieldType(560) - DLCLASSCODE_N_NOTES → const FieldType
-
DL class code N valid notes.
const FieldType(561) - DLCLASSCODE_N_TO → const FieldType
-
DL class code N valid to.
const FieldType(562) - DLCLASSCODE_S_FROM → const FieldType
-
DL class code S valid from.
const FieldType(563) - DLCLASSCODE_S_NOTES → const FieldType
-
DL class code S valid notes.
const FieldType(564) - DLCLASSCODE_S_TO → const FieldType
-
DL class code S valid to.
const FieldType(565) - DLCLASSCODE_TB_FROM → const FieldType
-
DL class code TB valid from.
const FieldType(566) - DLCLASSCODE_TB_NOTES → const FieldType
-
DL class code TB valid notes.
const FieldType(567) - DLCLASSCODE_TB_TO → const FieldType
-
DL class code TB valid to.
const FieldType(568) - DLCLASSCODE_TM_FROM → const FieldType
-
DL class code TM valid from.
const FieldType(569) - DLCLASSCODE_TM_NOTES → const FieldType
-
DL class code TM valid notes.
const FieldType(570) - DLCLASSCODE_TM_TO → const FieldType
-
DL class code TM valid to.
const FieldType(571) - DLCLASSCODE_TR_FROM → const FieldType
-
DL class code TR valid from.
const FieldType(572) - DLCLASSCODE_TR_NOTES → const FieldType
-
DL class code TR valid notes.
const FieldType(573) - DLCLASSCODE_TR_TO → const FieldType
-
DL class code TR valid to.
const FieldType(574) - DLCLASSCODE_TV_FROM → const FieldType
-
DL class code TV valid from.
const FieldType(575) - DLCLASSCODE_TV_NOTES → const FieldType
-
DL class code TV valid notes.
const FieldType(576) - DLCLASSCODE_TV_TO → const FieldType
-
DL class code TV valid to.
const FieldType(577) - DLCLASSCODE_V_FROM → const FieldType
-
DL class code V valid from.
const FieldType(578) - DLCLASSCODE_V_NOTES → const FieldType
-
DL class code V valid notes.
const FieldType(579) - DLCLASSCODE_V_TO → const FieldType
-
DL class code V valid to.
const FieldType(580) - DLCLASSCODE_W_FROM → const FieldType
-
DL class code W valid from.
const FieldType(581) - DLCLASSCODE_W_NOTES → const FieldType
-
DL class code W valid notes.
const FieldType(582) - DLCLASSCODE_W_TO → const FieldType
-
DL class code W valid to.
const FieldType(583) - URL → const FieldType
-
Uniform Resource Locator.
const FieldType(584) - CALIBER → const FieldType
-
Caliber.
const FieldType(585) - MODEL → const FieldType
-
Model.
const FieldType(586) - MAKE → const FieldType
-
Make.
const FieldType(587) - NUMBER_OF_CYLINDERS → const FieldType
-
Number of cylinders.
const FieldType(588) - SURNAME_OF_HUSBAND_AFTER_REGISTRATION → const FieldType
-
Surname of husband after registration.
const FieldType(589) - SURNAME_OF_WIFE_AFTER_REGISTRATION → const FieldType
-
Surname of wife after registration.
const FieldType(590) - DATE_OF_BIRTH_OF_WIFE → const FieldType
-
Wife's date of birth.
const FieldType(591) - DATE_OF_BIRTH_OF_HUSBAND → const FieldType
-
Husband's date of birth.
const FieldType(592) - CITIZENSHIP_OF_FIRST_PERSON → const FieldType
-
Citizenship of the first person.
const FieldType(593) - CITIZENSHIP_OF_SECOND_PERSON → const FieldType
-
Citizenship of the second person.
const FieldType(594) - CVV → const FieldType
-
Card Security Code.
const FieldType(595) - DATE_OF_INSURANCE_EXPIRY → const FieldType
-
Date of insurance expiry.
const FieldType(596) - MORTGAGE_BY → const FieldType
-
Mortgage by.
const FieldType(597) - OLD_DOCUMENT_NUMBER → const FieldType
-
Old document number.
const FieldType(598) - OLD_DATE_OF_ISSUE → const FieldType
-
Old date of issue.
const FieldType(599) - OLD_PLACE_OF_ISSUE → const FieldType
-
Old place of issue.
const FieldType(600) - DLCLASSCODE_LR_FROM → const FieldType
-
DL category LR valid from.
const FieldType(601) - DLCLASSCODE_LR_TO → const FieldType
-
DL category LR valid to.
const FieldType(602) - DLCLASSCODE_LR_NOTES → const FieldType
-
DL category LR valid notes.
const FieldType(603) - DLCLASSCODE_MR_FROM → const FieldType
-
DL category MR valid from.
const FieldType(604) - DLCLASSCODE_MR_TO → const FieldType
-
DL category MR valid to.
const FieldType(605) - DLCLASSCODE_MR_NOTES → const FieldType
-
DL category MR valid notes.
const FieldType(606) - DLCLASSCODE_HR_FROM → const FieldType
-
DL category HR valid from.
const FieldType(607) - DLCLASSCODE_HR_TO → const FieldType
-
DL category HR valid to.
const FieldType(608) - DLCLASSCODE_HR_NOTES → const FieldType
-
DL category HR valid notes.
const FieldType(609) - DLCLASSCODE_HC_FROM → const FieldType
-
DL category HC valid from.
const FieldType(610) - DLCLASSCODE_HC_TO → const FieldType
-
DL category HC valid to.
const FieldType(611) - DLCLASSCODE_HC_NOTES → const FieldType
-
DL category HC valid notes.
const FieldType(612) - DLCLASSCODE_MC_FROM → const FieldType
-
DL category MC valid from.
const FieldType(613) - DLCLASSCODE_MC_TO → const FieldType
-
DL category MC valid to.
const FieldType(614) - DLCLASSCODE_MC_NOTES → const FieldType
-
DL category MC valid notes.
const FieldType(615) - DLCLASSCODE_RE_FROM → const FieldType
-
DL category RE valid from.
const FieldType(616) - DLCLASSCODE_RE_TO → const FieldType
-
DL category RE valid to.
const FieldType(617) - DLCLASSCODE_RE_NOTES → const FieldType
-
DL category RE valid notes.
const FieldType(618) - DLCLASSCODE_R_FROM → const FieldType
-
DL category R valid from.
const FieldType(619) - DLCLASSCODE_R_TO → const FieldType
-
DL category R valid to.
const FieldType(620) - DLCLASSCODE_R_NOTES → const FieldType
-
DL category R valid notes.
const FieldType(621) - DLCLASSCODE_CA_FROM → const FieldType
-
DL category CA valid from.
const FieldType(622) - DLCLASSCODE_CA_TO → const FieldType
-
DL category CA valid to.
const FieldType(623) - DLCLASSCODE_CA_NOTES → const FieldType
-
DL category CA valid notes.
const FieldType(624) - CITIZENSHIP_STATUS → const FieldType
-
Citizenship status.
const FieldType(625) - MILITARY_SERVICE_FROM → const FieldType
-
Start date of military service.
const FieldType(626) - MILITARY_SERVICE_TO → const FieldType
-
End date of military service.
const FieldType(627) - DLCLASSCODE_NT_FROM → const FieldType
-
DL category NT valid notes.
const FieldType(628) - DLCLASSCODE_NT_TO → const FieldType
-
DL category NT valid to.
const FieldType(629) - DLCLASSCODE_NT_NOTES → const FieldType
-
DL category NT valid notes.
const FieldType(630) - DLCLASSCODE_TN_FROM → const FieldType
-
DL category TN valid from.
const FieldType(631) - DLCLASSCODE_TN_TO → const FieldType
-
DL category TN valid to.
const FieldType(632) - DLCLASSCODE_TN_NOTES → const FieldType
-
DL category TN valid notes.
const FieldType(633) - DLCLASSCODE_D3_FROM → const FieldType
-
DL category D3 valid from.
const FieldType(634) - DLCLASSCODE_D3_TO → const FieldType
-
DL category D3 valid to.
const FieldType(635) - DLCLASSCODE_D3_NOTES → const FieldType
-
DL category D3 valid notes.
const FieldType(636) - ALT_DATE_OF_EXPIRY → const FieldType
-
Alternative date of expiry.
const FieldType(637) - DLCLASSCODE_CD_FROM → const FieldType
-
DL category CD valid from.
const FieldType(638) - DLCLASSCODE_CD_TO → const FieldType
-
DL category CD valid to.
const FieldType(639) - DLCLASSCODE_CD_NOTES → const FieldType
-
DL category CD valid notes.
const FieldType(640) - PAYMENT_PERIOD_TO → const FieldType
-
End date of payment period.
const FieldType(643) - PAYMENT_PERIOD_FROM → const FieldType
-
Start date of payment period.
const FieldType(642) - ISSUER_IDENTIFICATION_NUMBER → const FieldType
-
Issuer identification number (IIN).
const FieldType(641) - VACCINATION_CERTIFICATE_IDENTIFIER → const FieldType
-
Vaccination certificate identifier.
const FieldType(644) - FIRST_NAME → const FieldType
-
First name.
const FieldType(645) - DATE_OF_ARRIVAL → const FieldType
-
Date of arrival.
const FieldType(646) - SECOND_NAME → const FieldType
-
Second name.
const FieldType(647) - THIRD_NAME → const FieldType
-
Third name.
const FieldType(648) - FOURTH_NAME → const FieldType
-
Fourth name.
const FieldType(649) - LAST_NAME → const FieldType
-
Last name.
const FieldType(650) - DLCLASSCODE_RM_FROM → const FieldType
-
DL class code RM valid from.
const FieldType(651) - DLCLASSCODE_RM_NOTES → const FieldType
-
DL class code RM notes.
const FieldType(652) - DLCLASSCODE_RM_TO → const FieldType
-
DL class code RM valid to.
const FieldType(653) - DLCLASSCODE_PW_FROM → const FieldType
-
DL class code PW valid from.
const FieldType(654) - DLCLASSCODE_PW_NOTES → const FieldType
-
DL class code PW notes.
const FieldType(655) - DLCLASSCODE_PW_TO → const FieldType
-
DL class code PW valid to.
const FieldType(656) - DLCLASSCODE_EB_FROM → const FieldType
-
const FieldType(657) - DLCLASSCODE_EB_NOTES → const FieldType
-
const FieldType(658) - DLCLASSCODE_EB_TO → const FieldType
-
const FieldType(659) - DLCLASSCODE_EC_FROM → const FieldType
-
const FieldType(660) - DLCLASSCODE_EC_NOTES → const FieldType
-
const FieldType(661) - DLCLASSCODE_EC_TO → const FieldType
-
const FieldType(662) - DLCLASSCODE_EC1_FROM → const FieldType
-
const FieldType(663) - DLCLASSCODE_EC1_NOTES → const FieldType
-
const FieldType(664) - DLCLASSCODE_EC1_TO → const FieldType
-
const FieldType(665) - PLACE_OF_BIRTH_CITY → const FieldType
-
const FieldType(666) - YEAR_OF_BIRTH → const FieldType
-
const FieldType(667) - YEAR_OF_EXPIRY → const FieldType
-
const FieldType(668) - GRANDFATHER_NAME_MATERNAL → const FieldType
-
const FieldType(669) - FIRST_SURNAME → const FieldType
-
const FieldType(670) - MONTH_OF_BIRTH → const FieldType
-
const FieldType(671) - ADDRESS_FLOOR_NUMBER → const FieldType
-
const FieldType(672) - ADDRESS_ENTRANCE → const FieldType
-
const FieldType(673) - ADDRESS_BLOCK_NUMBER → const FieldType
-
const FieldType(674) - ADDRESS_STREET_NUMBER → const FieldType
-
const FieldType(675) - ADDRESS_STREET_TYPE → const FieldType
-
const FieldType(676) - ADDRESS_CITY_SECTOR → const FieldType
-
const FieldType(677) - ADDRESS_COUNTY_TYPE → const FieldType
-
const FieldType(678) - ADDRESS_CITY_TYPE → const FieldType
-
const FieldType(679) - ADDRESS_BUILDING_TYPE → const FieldType
-
const FieldType(680) - DATE_OF_RETIREMENT → const FieldType
-
Date of retirement.
const FieldType(681) - DOCUMENT_STATUS → const FieldType
-
Document status.
const FieldType(682) - SIGNATURE → const FieldType
-
Signature.
const FieldType(683) - UNIQUE_CERTIFICATE_IDENTIFIER → const FieldType
-
Unique certificate identifier.
const FieldType(684) - EMAIL → const FieldType
-
Email.
const FieldType(685) - DATE_OF_SPECIMEN_COLLECTION → const FieldType
-
Date of specimen collection.
const FieldType(686) - TYPE_OF_TESTING → const FieldType
-
Type of testing.
const FieldType(687) - RESULT_OF_TESTING → const FieldType
-
Result of testing.
const FieldType(688) - METHOD_OF_TESTING → const FieldType
-
Method of testing.
const FieldType(689) - DIGITAL_TRAVEL_AUTHORIZATION_NUMBER → const FieldType
-
const FieldType(690) - DATE_OF_FIRST_POSITIVE_TEST_RESULT → const FieldType
-
Date of first positive test result.
const FieldType(691) - EF_CARD_ACCESS → const FieldType
-
const FieldType(692) - SHORT_FLIGHT_NUMBER → const FieldType
-
const FieldType(693) - AIRLINE_CODE → const FieldType
-
const FieldType(694) - MVC_AGENCY → const FieldType
-
const FieldType(695) - ISSUING_STATE_CODE_ALPHA_2 → const FieldType
-
const FieldType(696) - NATIONALITY_CODE_ALPHA_2 → const FieldType
-
const FieldType(697) - FIRST_ISSUE_DATE_CHECKDIGIT → const FieldType
-
const FieldType(698) - FIRST_ISSUE_DATE_CHECKSUM → const FieldType
-
const FieldType(699) - COMMERCIAL_INDICATOR → const FieldType
-
const FieldType(701) - NON_DOMICILED_INDICATOR → const FieldType
-
const FieldType(702) - JURISDICTION_SPECIFIC_DATA → const FieldType
-
const FieldType(703)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
getTranslation(
) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromIntList(
List? input) → List< FieldType> ? -
getByValue(
int? i) → FieldType?