File class

Constructors

File()

Properties

certificates → SecurityObjectCertificates?
no setter
docFieldsGraphics → List<int>
no setter
docFieldsOriginals → List<int>
no setter
docFieldsText → List<int>
no setter
fileData → FileData?
no setter
fileID → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
notifications → List<int>
no setter
pAStatus → RFIDErrorCodes
no setter
readingStatus → RFIDErrorCodes
no setter
readingTime → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RFIDDataFileType
no setter
typeName → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → File?
Allows you to deserialize object.