Font class

Constructors

Font(String name, {int? size, FontStyle? style})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Font family.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
Font size.
no setter
style → FontStyle?
Font style.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Font?
Allows you to deserialize object.