Functionality class

Params that influence the scanning process, camera view controller customization and etc.

Constructors

Functionality()

Properties

btDeviceName ↔ String?
Allows you to specify a name of a Regula device that will be used with Document Reader SDK.
getter/setter pair
cameraFrame ↔ DocReaderFrame?
Set this setting to override the default cropping frame provided by scenarios.
getter/setter pair
cameraMode ↔ CameraMode?
Allows you to specify the camera API.
getter/setter pair
cameraPositionIOS ↔ CameraPosition?
Allows you to specify a position of a capture device for the video session.
getter/setter pair
cameraResolutionAndroid ↔ CameraSize?
Allows you to specify the frame resolution.
getter/setter pair
cameraResolutionIOS ↔ CaptureSessionPreset?
Allows you to specify the frame resolution.
getter/setter pair
captureMode ↔ CaptureMode?
Allows you to specify the video processing mode.
getter/setter pair
displayMetadata ↔ bool?
If it's set to true, the metadata will be displayed over the camera preview during document processing, namely the perspective angle value.
getter/setter pair
excludedCamera2Models ↔ List<String>?
A list of devices that must not use the camera2 API.
getter/setter pair
exposure ↔ double?
Allows you to control exposure.
getter/setter pair
forcePagesCount ↔ int?
Sets a limit on the number of pages to be processed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideStatusBar ↔ bool?
Android only.
getter/setter pair
homeIndicatorAutoHide ↔ bool?
If it's set to true, system is allowed to hide the visual indicator for returning to the Home Screen in landscape mode.
getter/setter pair
isCameraTorchCheckDisabled ↔ bool?
Allows you to disable all validations of having a torch in case Android returns that it's not available, but it can be used when checks are skipped.
getter/setter pair
isZoomEnabled ↔ bool?
If it's set to true, allows you to adjust a zoom level using the pinch gesture (its range is from 1x to 10x).
getter/setter pair
manualMultipageMode ↔ bool?
If it's set to true, scanner operate in manual multipage scanning mode. Set this flag to true, if you wanna create for example, custom logic (or UI) between scanning document pages.
getter/setter pair
mdlTimeout ↔ double?
getter/setter pair
orientation ↔ DocReaderOrientation?
Allows you to specify an orientation of the camera view controller.
getter/setter pair
pictureOnBoundsReady ↔ bool?
If set to true, as soon as document is located during video mode, picture wil be taken and processed as single frame.
getter/setter pair
preventScreenRecording ↔ bool?
When enabled, the SDK prevents both screen recording and screenshots.
getter/setter pair
recordScanningProcess ↔ bool?
If set to true, video during processing of the document will be recorded. This can be used later for debugging and troubleshooting.
getter/setter pair
rfidTimeout ↔ int?
Use the parameter to set the time limit (in seconds) for the RFID chip reading, beyond which it does not continue regardless of its result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCameraSwitchButton ↔ bool?
If it's set to true, the button that allows you to change a position of a capture device for the video session will be displayed.
getter/setter pair
showCaptureButton ↔ bool?
If it's set to true, the button that allows you to take a picture and process it as a single frame will be displayed.
getter/setter pair
showCaptureButtonDelayFromDetect ↔ int?
Allows you to specify a time interval when the Capture button has to be displayed after the document is detected. Don't forget to set the showCaptureButton to true, otherwise, it won't be displayed.
getter/setter pair
showCaptureButtonDelayFromStart ↔ int?
Allows you to specify a time interval when the Capture button has to be displayed after the scanning process is started. Don't forget to set the showCaptureButton to true, otherwise, it won't be displayed.
getter/setter pair
showChangeFrameButton ↔ bool?
If it's set to true, the button that allows you to change the camera frame type will be displayed.
getter/setter pair
showCloseButton ↔ bool?
If it's set to true, the button that allows you to close the scanner will be displayed.
getter/setter pair
showSkipNextPageButton ↔ bool?
If it's set to true, the button that allows you to skip processing of the next page of a document will be displayed.
getter/setter pair
showTorchButton ↔ bool?
If it's set to true, the button that allows you to turn on/off the torch will be displayed.
getter/setter pair
singleResult ↔ bool?
If it's set to true, once the scanning process is finished, the scanner will be dismissed.
getter/setter pair
skipFocusingFrames ↔ bool?
If it's set to true, camera frames won't be taken for recognition while a camera is focusing.
getter/setter pair
testSetters ↔ Map<String, dynamic>
getter/setter pair
torchTurnedOn ↔ bool?
If set, torch (if available) will turn on immediately on camera preview start.
getter/setter pair
useAuthenticator ↔ bool?
If it's set to true, allows you to connect to the external Regula Bluetooth devices like Regula 1120 and others.
getter/setter pair
videoCaptureMotionControl ↔ bool?
If it's set to true, camera frames won't be taken for recognition while a device is moving based on motion sensors.
getter/setter pair
videoRecordingSizeDownscaleFactor ↔ double?
Android only.
getter/setter pair
zoomFactor ↔ double?
Allows you to set the desired zoom level (its range from 1x to 10x).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Functionality
Allows you to deserialize object.