GraphicField class

Structure, describing single graphic field extracted.

Constructors

GraphicField()

Properties

fieldName → String
Graphic field symbolic name.
no setter
fieldRect → Rect?
Field area coordinates on the general image.
no setter
fieldType → GraphicFieldType
Graphic field logical type.
no setter
hashCode → int
The hash code for this object.
no setterinherited
light → Lights
Light type.
no setter
lightName → String
Light symbolic name.
no setter
originalPageIndex → int
Original page index.
no setter
pageIndex → int
An index of the document page whence the graphic field is extracted.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → ResultType
Identifies zone whence data is extracted.
no setter
value → Uint8List?
An image.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → GraphicField?
Allows you to deserialize object.