ImageInputData class

Constructors

ImageInputData(Uint8List image, {Lights light = Lights.WHITE_FULL, int pageIndex = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
image → Uint8List
An image.
no setter
light → Lights
Light type, one of RGLGraphicFieldLight values.
no setter
pageIndex → int
An index of the document page whence the graphic field is extracted.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ImageInputData?