ImageQA class

Class contains properties to configure image quality.

Constructors

ImageQA()

Properties

angleThreshold ↔ int?
This parameter sets threshold for Image QA check of the presented document perspective angle in degrees. If actual document perspective angle is above this threshold, check will fail.
getter/setter pair
brightnessThreshold ↔ double?
Set the threshold for an actual document brightness below which the check fails.
getter/setter pair
colornessCheck ↔ bool?
This option disabled colorness check during performing image quality validation.
getter/setter pair
documentPositionIndent ↔ int?
Specify the minimum indent from the corners of the document to the borders of the image. The value reflects the allowed percentage for the indent relative to the width of the document. If it is detected that the corners of the document are closer than the specified value, the status will contain an error in the DocumentReaderResults.imageQuality.imageQualityList.result field.
getter/setter pair
dpiThreshold ↔ int?
This parameter sets threshold for Image QA check of the presented document physical dpi. If actual document dpi is below this threshold, check will fail.
getter/setter pair
expectedPass ↔ List<ImageQualityCheckType>?
This option controls the quality checks that the image should pass in order to be considered a valid input during the scanning process.
getter/setter pair
focusCheck ↔ bool?
This option disabled focus check during performing image quality validation.
getter/setter pair
glaresCheck ↔ bool?
This option disabled glares check during performing image quality validation.
getter/setter pair
glaresCheckParams ↔ GlaresCheckParams?
Parameters for glares image quality validation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
occlusionCheck ↔ bool?
This option checks document image occlusion.
getter/setter pair
occlusionCheckParams ↔ OcclusionCheckParams?
Parameters for occlusion image quality validation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenCapture ↔ bool?
This option disabled moire patterns check during performing image quality validation.
getter/setter pair
testSetters ↔ Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ImageQA
Allows you to deserialize object.