ImageQuality class

Structure, containing information about single image quality check.

Constructors

ImageQuality()

Properties

boundRects → List<Rect>
Coordinates of glares.
no setter
featureType → int
Check result.
no setter
hashCode → int
The hash code for this object.
no setterinherited
result → CheckResult
Check result.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ImageQualityCheckType
Check result type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ImageQuality?
Allows you to deserialize object.