ImageQualityGroup class

Structure, containing overall data about quality checks performed.

Constructors

ImageQualityGroup()

Properties

count → int
Number of results.
no setter
hashCode → int
The hash code for this object.
no setterinherited
imageQualityList → List<ImageQuality>
An array of single check result pointers.
no setter
pageIndex → int
Index of the document page, whence the result is received.
no setter
result → CheckResult
Overall check result for document page.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ImageQualityGroup?
Allows you to deserialize object.