InitConfig class

A configuration file for DocumentReader initialization. Controls initialization time properties such as licenseUpdate and delayedNNLoad.

Constructors

InitConfig(ByteData license)
Constructor for initialization using a license binary.
InitConfig.withBleDevice()
Constructor for initialization using a ble device. Doesn't need a license file, it will be fetched automatically from your ble device.

Properties

blackList ↔ Map<String, dynamic>?
Android only.
getter/setter pair
customDb ↔ ByteData?
Custom database binary.
getter/setter pair
databasePath ↔ String?
The path to the database file.
getter/setter pair
delayedNNLoad ↔ bool
Defines whether the DocumentReader delays loading of neural networks.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
license → ByteData
The license binary file.
no setter
licenseUpdate ↔ bool
Enables automatic license update check during DocumentReader initialization.
getter/setter pair
licenseUpdateTimeout ↔ double?
Allows you to configure the maximum time needed for a license update (in seconds).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → InitConfig?