License class

Class contains properties to get the information about the license.

Constructors

License()

Properties

countryFilter → List<String>?
Allows you to get a list of country identifiers which are defined for processing in the license. If the array is empty, there are no restrictions for processing.
no setter
expiryDate → String?
Allows you to get an expiration date of your license.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isRfidAvailable → bool
Allows you to verify that RFID chip reading capabilities are added to your license.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → License?