LivenessParams class

Constructors

LivenessParams()

Properties

checkBarcodeBackground ↔ bool?
This parameter is used to enable Barcode background check as part of the Liveness checks.
getter/setter pair
checkBlackAndWhiteCopy ↔ bool?
getter/setter pair
checkDynaprint ↔ bool?
This parameter is used to enable Dynaprint detection.
getter/setter pair
checkED ↔ bool?
getter/setter pair
checkGeometry ↔ bool?
getter/setter pair
checkHolo ↔ bool?
getter/setter pair
checkMLI ↔ bool?
getter/setter pair
checkOVI ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testSetters ↔ Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → LivenessParams
Allows you to deserialize object.