OnlineProcessingConfig class

Constructors

OnlineProcessingConfig(OnlineMode mode)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageCompressionQuality ↔ double
getter/setter pair
imageFormat ↔ ImageFormat
getter/setter pair
mode ↔ OnlineMode
getter/setter pair
processParams ↔ ProcessParams
getter/setter pair
requestHeaders ↔ Map<String, String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → OnlineProcessingConfig?