OpticalStatus class

Container for an optical related scanning statuses.

Constructors

OpticalStatus()

Properties

docType → CheckResult
Check status if document type was recognized or not.
no setter
expiry → CheckResult
Document validity period verification status.
no setter
hashCode → int
The hash code for this object.
no setterinherited
imageQA → CheckResult
Input images quality verification status.
no setter
mrz → CheckResult
MRZ verification: values validity, dates, checkdigits verification.
no setter
overallStatus → CheckResult
Summary of all optical results.
no setter
pagesCount → int
Number of scanned document pages.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
security → CheckResult
Authenticity verification status.
no setter
text → CheckResult
Text fields valitity: values validity for specific fields, cross-comparison of values from different sources, dates & checkdigits verification.
no setter
vds → CheckResult
Visible Digital Seal verification status.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → OpticalStatus?
Allows you to deserialize object.