PACEProtocol class

Constructors

PACEProtocol()

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyAlgorithm → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stdDomainParams → String
no setter
version → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → PACEProtocol?