PKDCertificate class

Class contains information about PKD certificate.

Constructors

PKDCertificate(ByteData binaryData, PKDResourceType resourceType, {ByteData? privateKey})

Properties

binaryData → ByteData
Certificate in binary type.
no setter
hashCode → int
The hash code for this object.
no setterinherited
privateKey → ByteData?
Private key in binary type.
no setter
resourceType → PKDResourceType
Indicates type of certificate.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → PKDCertificate?