Position class

Structure is used for storing element bounds detection result._

Constructors

Position()

Properties

angle → double
Document rotation angle.
no setter
center → Coordinate?
Document center coordinates.
no setter
docFormat → DocFormat
Document format.
no setter
dpi → int
Resolution in dots per inch.
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
Document height.
no setter
inverse → int
Internal use parameter.
no setter
leftBottom → Coordinate?
Document left bottom corner coordinates.
no setter
leftTop → Coordinate?
Document left top corner coordinates.
no setter
objArea → int
Internal use parameter.
no setter
objIntAngleDev → int
Internal use parameter.
no setter
pageIndex → int
Index of the document page, whence the result is received.
no setter
perspectiveTr → int
Internal use parameter.
no setter
resultStatus → CheckResult
Internal use parameter.
no setter
rightBottom → Coordinate?
Document right bottom corner coordinates.
no setter
rightTop → Coordinate?
Document right top corner coordinates.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Document width.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Position?
Allows you to deserialize object.