RFIDAccessControl enum

Inheritance
Available extensions

Values

DEFAULT → const RFIDAccessControl
const RFIDAccessControl(0)
CHIP_ACCESS_BAC → const RFIDAccessControl
const RFIDAccessControl(1)
CHIP_ACCESS_PACE → const RFIDAccessControl
const RFIDAccessControl(2)
LOCAL_PIN → const RFIDAccessControl
const RFIDAccessControl(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getByValue(int? i) → RFIDAccessControl?

Constants

values → const List<RFIDAccessControl>
A constant List of the values in this enum, in order of their declaration.