RFIDConfig class

A configuration file for the RFID chip processing.

Constructors

RFIDConfig(DocumentReaderCompletion completion)
Regular RFID chip reading.
RFIDConfig.withoutUI(RFIDCompletion completion)
RFID chip reading with no UI.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onChipDetected ↔ ChipDetectedCompletion?
Callback for receiving signal when RFID chip is recognized by a phone and chip reading is started.
getter/setter pair
onProgress ↔ RFIDProgressCompletion?
Callback for reveiving notification about RFID reading process.
getter/setter pair
onRequestCAProtocol ↔ CAProtocolCompletion?
Callback for receiving RFID request data
getter/setter pair
onRequestPACEProtocol ↔ PACEProtocolCompletion?
Callback for receiving RFID request data
getter/setter pair
onRequestPACertificates ↔ PaCertificateCompletion?
Callback for receiving RFID request data
getter/setter pair
onRequestTACertificates ↔ TaCertificateCompletion?
Callback for receiving RFID request data
getter/setter pair
onRequestTASignature ↔ TaSignatureCompletion?
Callback for receiving RFID request data
getter/setter pair
onRetryReadChip ↔ RetryReadChipCompletion?
Fires when RFID chip reading was interrupted with no severe reasons (for example connection to the chip was lost) and will be reestablished automatically.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited