RFIDNotification class

Structure containing data of notification about RFID reading process.

Constructors

RFIDNotification()

Properties

dataFileType → RFIDDataFileType
Defines the file type (or logical belonging of the data object) within the context of the communication session with electronic document.
no setter
hashCode → int
The hash code for this object.
no setterinherited
notificationCode → RFIDNotificationCodes
RFID notification code.
no setter
progress → int
RFID progress.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → RFIDNotification?