RFIDNotificationCodes enum

Enumeration contains a set of notification returned to the user application by calling the callback-function.

Inheritance
Available extensions

Values

UNKNOWN → const RFIDNotificationCodes

Will be returned by getByValue if a non-existent value was passed.

const RFIDNotificationCodes(-1)
ERROR → const RFIDNotificationCodes

The notification indicates an error.

const RFIDNotificationCodes(65536)
DOCUMENT_READY → const RFIDNotificationCodes

Event of appearance of RFID-chip in the scope of the reader antenna or its moving away from the scope of the reader.

const RFIDNotificationCodes(65537)
READ_PROTOCOL4 → const RFIDNotificationCodes

Event of the beginning/end of data reading from the RFID-chip via ISO/IEC 14443-4 proto-col When working in the batch mode.

const RFIDNotificationCodes(65539)
READ_PROTOCOL3 → const RFIDNotificationCodes

Event of the beginning/end of data reading from the RFID-chip via ISO/IEC 14443-3 proto-col.

const RFIDNotificationCodes(65546)
PROGRESS → const RFIDNotificationCodes

Indication of the progress of execution of data reading operation.

const RFIDNotificationCodes(65547)
TA_STEP → const RFIDNotificationCodes

Indication of the next step of terminal authentication in Online-authentication mode.

const RFIDNotificationCodes(65550)
SM_REQUIRED → const RFIDNotificationCodes

Event of detection of the need to organize a secure communication channel.

const RFIDNotificationCodes(65551)
ISO_ERROR → const RFIDNotificationCodes

Event informing the user application on detection of data incompliance processed with the regulations of normative documents, errors when executing the current operation.

const RFIDNotificationCodes(69632)
PA_REQUEST → const RFIDNotificationCodes

Request of the user-defined DS-certificate priot to the procedure of digital signature verifi-cation of EF.SOD document security object in the batch mode.

const RFIDNotificationCodes(77824)
SM_ESTABLISHED → const RFIDNotificationCodes

Event of the result of the opening of a secure communication channel.

const RFIDNotificationCodes(81935)
PCSC_READER_DISCONNECTED → const RFIDNotificationCodes

Event of unplugging of the RFID-chip reader from the PC.

const RFIDNotificationCodes(131072)
PCSC_READER_LIST_CHANGED → const RFIDNotificationCodes

Event of the beginning of reorganization of the list of RFID-readers connected to the PC, working under PC/SC-driver control.

const RFIDNotificationCodes(131073)
PCSC_BYTES_RECEIVED → const RFIDNotificationCodes

Transfer of the total amount of information received from the RFID-chip to the user appli-cation during execution of data reading operation.

const RFIDNotificationCodes(131074)
PCSC_TOTAL_READING_TIME → const RFIDNotificationCodes

Transfer of the total time of execution of data reading operation to the user application.

const RFIDNotificationCodes(131075)
PCSC_DATA_RECEIVED → const RFIDNotificationCodes

Transfer of the total amount of information and service groups data received from the RF-ID-chip to the user application during execution of data reading operation.

const RFIDNotificationCodes(131076)
PCSC_BYTES_SENT → const RFIDNotificationCodes

Transfer of the total amount of information transmitted to the RFID-chip to the user appli-cation during execution of data reading operation.

const RFIDNotificationCodes(131077)
PCSC_TOTAL_READING_SPEED → const RFIDNotificationCodes

Transfer of the average data reading rate to the user application.

const RFIDNotificationCodes(131078)
PCSC_TOTAL_PROCESS_TIME → const RFIDNotificationCodes

Transfer of the total time of execution of data reading procedure to the user application.

const RFIDNotificationCodes(131079)
PCSC_READER_LIST_CHANGING → const RFIDNotificationCodes

Event of the beginning of reorganization of the list of RFID-readers connected to the PC, working under PC/SC-driver control.

const RFIDNotificationCodes(131080)
PCSC_EXT_LENGTH_SUPPORT → const RFIDNotificationCodes

Event of detection of extended length reading commands support by the RFID-chip.

const RFIDNotificationCodes(131088)
PA_CERTIFICATE_CHAIN → const RFIDNotificationCodes

Event of the start/end of the certificate chain formation for the document security object digital signature verification as a part of passive authentication procedure.

const RFIDNotificationCodes(131089)
PA_CERTIFICATE_CHAIN_ITEM → const RFIDNotificationCodes

Event that indicates a type of the current analyzed element of the certificate chain being composed.

All subsequent notifications prior to the next PA_CERTIFICATE_CHAIN_ITEM or PA_CERTIFICATE_CHAIN will correspond to this element.

const RFIDNotificationCodes(131090)
SCENARIO → const RFIDNotificationCodes

A request from the user application of some data or actions in a certain step of the scenario.

const RFIDNotificationCodes(131104)
PCSC_READING_DATAGROUP → const RFIDNotificationCodes

Event of the beginning/end of file reading.

const RFIDNotificationCodes(196608)
PCSC_FILE_NOT_FOUND → const RFIDNotificationCodes

Event of detection of file absence.

const RFIDNotificationCodes(262144)
PCSC_END_OF_FILE → const RFIDNotificationCodes

Event of reaching the file end when performing its reading.

const RFIDNotificationCodes(327680)
PCSC_FILE_ACCESS_DENIED → const RFIDNotificationCodes

Event of detection of absence of the file access rights.

const RFIDNotificationCodes(393216)
PCSC_APPLICATION_SELECTED → const RFIDNotificationCodes

Event of the application selection operation.

const RFIDNotificationCodes(458752)
AC_PROCEDURE_START → const RFIDNotificationCodes

Event of the beginning of the authentication or secure data access procedure.

const RFIDNotificationCodes(524288)
AC_PROCEDURE_FINISH → const RFIDNotificationCodes

Event of the end of the authentication or secure data access procedure.

const RFIDNotificationCodes(589824)
PA_SECURITY_OBJECT_CHECK → const RFIDNotificationCodes

Event of the data security object verification as part of PA.

const RFIDNotificationCodes(655360)
PA_FILE_CHECK → const RFIDNotificationCodes

Event of the file data integrity checking as part of PA.

const RFIDNotificationCodes(720896)
PCSC_UPDATING_DATAGROUP → const RFIDNotificationCodes

Event of the procedure of file contents updating.

const RFIDNotificationCodes(786432)
AUXILIARY_DATA_VALIDATION → const RFIDNotificationCodes

Event of the auxiliary data verification.

const RFIDNotificationCodes(851968)
RI_SECTOR_ID → const RFIDNotificationCodes

Event of the receiving of the sector identifier data during RI.

const RFIDNotificationCodes(917504)
BIOMETRICS_EMPTY_PLACEHOLDER → const RFIDNotificationCodes

Event of the detection of real biometric data absence in DG3 or DG4 and random filling data usage.

const RFIDNotificationCodes(983040)
SESSION_FILE_DATA_UPDATED → const RFIDNotificationCodes
const RFIDNotificationCodes(1048576)
TCC_TA_RESOURCES → const RFIDNotificationCodes
const RFIDNotificationCodes(1114112)
TCC_TA_SIGNATURE → const RFIDNotificationCodes
const RFIDNotificationCodes(1114113)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByValue(int? i) RFIDNotificationCodes?

Constants

values → const List<RFIDNotificationCodes>
A constant List of the values in this enum, in order of their declaration.