RFIDSessionData class

Used to describe the results of work with the SDK within the context of the current communication session with electronic document.

Constructors

RFIDSessionData()

Properties

accessControls → List<AccessControlProcedureType>
List of containers to store information about the supported procedures of authentication and secure data access within the context of the session.
no setter
applications → List<Application>
List of containers to store information about the involved ap-plications of electronic document.
no setter
cardProperties → CardProperties?
Set of electronic document chip characteristics.
no setter
dataFields → List<DataField>
List of data fields
no setter
dataGroups → List<RFIDDataFileType>?
List of data groups.
no setter
extLeSupport → RFIDErrorCodes
Sign of support of RFID-chip for extended length commands of reading.
no setter
hashCode → int
The hash code for this object.
no setterinherited
processTime → int
Total time of all operations performed during the session, ms.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityObjects → List<SecurityObject>
ist of containers to store information about the detected document security objects.
no setter
status → RFIDErrorCodes
Status.
no setter
totalBytesReceived → int
Total number of bytes received from the RFID-chip during the whole session.
no setter
totalBytesSent → int
Total number of bytes transmitted to the RFID-chip during the whole session.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → RFIDSessionData?
Allows you to deserialize object.