RFIDSessionDataStatus class

Constructors

RFIDSessionDataStatus()

Properties

AA ↔ int?
getter/setter pair
BAC ↔ int?
getter/setter pair
CA ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
overallStatus ↔ int?
getter/setter pair
PA ↔ int?
getter/setter pair
PACE ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TA ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → RFIDSessionDataStatus?