RFIDStatus class

Container for a RFID related scanning statuses.

Constructors

RFIDStatus()

Properties

aa → CheckResult
Acitve authentication status.
no setter
bac → CheckResult
Basics access control status.
no setter
ca → CheckResult
Chip authentication status.
no setter
hashCode → int
The hash code for this object.
no setterinherited
overallStatus → CheckResult
Summary of all RFID results.
no setter
pa → CheckResult
Passive authentication status.
no setter
pace → CheckResult
Password authenticated connection establishment status.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ta → CheckResult
Terminal authentication status.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → RFIDStatus?
Allows you to deserialize object.