RecognizeConfig class

Image processing configuration.

Constructors

RecognizeConfig.withOnlineProcessingConfig(OnlineProcessingConfig onlineProcessingConfig, {Uint8List? image, List<Uint8List>? images, Uint8List? data, List<Uint8List>? dataList, List<ImageInputData>? imageInputData, Uint8List? dtc, Uint8List? livePortrait, Uint8List? extPortrait, bool oneShotIdentification = false})
RecognizeConfig.withScenario(Scenario scenario, {Uint8List? image, List<Uint8List>? images, Uint8List? data, List<Uint8List>? dataList, List<ImageInputData>? imageInputData, Uint8List? dtc, Uint8List? livePortrait, Uint8List? extPortrait, bool oneShotIdentification = false})

Properties

data ↔ Uint8List?
Binary for processing.
getter/setter pair
dataList ↔ List<Uint8List>?
Binaries for processing.
getter/setter pair
dtc ↔ Uint8List?
DTC file for processing.
getter/setter pair
extPortrait ↔ Uint8List?
Portrait photo from an external source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ Uint8List?
Image for processing.
getter/setter pair
imageInputData ↔ List<ImageInputData>?
Images(with input data) for processing.
getter/setter pair
images ↔ List<Uint8List>?
Images for processing.
getter/setter pair
livePortrait ↔ Uint8List?
Live portrait photo.
getter/setter pair
oneShotIdentification ↔ bool
This parameter is for processing an image that contains a person and a document and compare the portrait photo from the document with the person's face. It works only in the single-frame processing, but not in the video frame processing. Requires network connection.
getter/setter pair
onlineProcessingConfig → OnlineProcessingConfig?
Configuration class for online processing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenario → Scenario?
Documents processing scenario.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → RecognizeConfig?