Results class

Class describing results returned on completion of Document Reader work.

Constructors

Results()

Properties

authenticityResult → AuthenticityResult?
Authenticity results.
no setter
barcodePosition → List<Position>?
Position of a barcode.
no setter
barcodeResult → BarcodeResult?
Barcode results.
no setter
bsiTr03135Results → String?
Contains results in accordance with the BSI TR-03135 standard.
no setter
chipPage → int
Indicates which page of the document contains an RFID chip (0 if there's no page containing it). Requires document type recognition, otherwise 1 by default.
no setter
documentPosition → List<Position>?
Position of a document.
no setter
documentType → List<DocumentType>?
Document type results.
no setter
dtcData → Uint8List?
DTCVC data.
no setter
elapsedTime → int
Indicates how much time has been required for document processing, milliseconds.
no setter
elapsedTimeRFID → int
Indicates how much time has been required for RFID chip processing, milliseconds.
no setter
graphicResult → GraphicResult?
Graphic results.
no setter
hashCode → int
The hash code for this object.
no setterinherited
imageQuality → List<ImageQualityGroup>?
Image quality results.
no setter
morePagesAvailable → int
Indicates how many pages of a document remains to process. Requires Document Type recognition, otherwise 0 by default.
no setter
mrzPosition → List<Position>?
Position of MRZ.
no setter
processingFinishedStatus → ProcessingFinishedStatus
Document processing finish status, one of RGLProcessingFinishedStatus values.
no setter
rawResult → String
Raw results, i.e. in their initial view.
no setter
rfidSessionData → RFIDSessionData?
RFID session data.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ResultsStatus
Status information for each operation.
no setter
textResult → TextResult?
Textual results.
no setter
transactionInfo → TransactionInfo?
no setter
vdsData → VDSData?
Visible Digital Seal data.
no setter
vdsncData → VDSNCData?
Visible Digital Seal data.
no setter

Methods

containers(List<ResultType> resultType) → Future<String?>
Method returns containers by result type. If result type doesn't exist, the result of the search will be null.
encryptedContainers() → Future<String?>
Method returns only containers for ResultType.INTERNAL_RFID_SESSION, ResultType.INTERNAL_ENCRYPTED_RCL and ResultType.INTERNAL_LICENSE values.
graphicFieldByTypeSource(GraphicFieldType fieldType, ResultType source) → Future<GraphicField?>
Allows you to get an image of a graphic field based on a source type and page index.
graphicFieldByTypeSourcePageIndex(GraphicFieldType fieldType, ResultType source, int pageIndex) → Future<GraphicField?>
Allows you to get an image of a graphic field based on a source type and page index.
graphicFieldByTypeSourcePageIndexLight(GraphicFieldType fieldType, ResultType source, int pageIndex, Lights light) → Future<GraphicField?>
Allows you to get an image of a graphic field based on a source type, page index and light type.
graphicFieldImageByType(GraphicFieldType fieldType) → Future<Uint8List?>
Allows you to get an image of a graphic field.
graphicFieldImageByTypeSource(GraphicFieldType fieldType, ResultType source) → Future<Uint8List?>
Allows you to get an image of a graphic field based on a source type.
graphicFieldImageByTypeSourcePageIndex(GraphicFieldType fieldType, ResultType source, int pageIndex) → Future<Uint8List?>
Allows you to get an image of a graphic field based on a source type and page index.
graphicFieldImageByTypeSourcePageIndexLight(GraphicFieldType fieldType, ResultType source, int pageIndex, Lights light) → Future<Uint8List?>
Allows you to get an image of a graphic field based on a source type, page index and light type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textFieldByType(FieldType fieldType) → Future<TextField?>
Allows you to get an instance of a text field.
textFieldByTypeLcid(FieldType fieldType, LCID lcid) → Future<TextField?>
Allows you to get an instance of a text field based on LCID.
textFieldValueByType(FieldType fieldType) → Future<String?>
Allows you to get a value of a text field.
textFieldValueByTypeLcid(FieldType fieldType, LCID lcid) → Future<String?>
Allows you to get a value of a text field based on LCID.
textFieldValueByTypeLcidSource(FieldType fieldType, LCID lcid, ResultType source) → Future<String?>
Allows you to get a value of a text field based on LCID and a source type.
textFieldValueByTypeLcidSourceOriginal(FieldType fieldType, LCID lcid, ResultType source, bool original) → Future<String?>
Allows you to get a value of a text field based on LCID, a source type and its originality.
textFieldValueByTypeSource(FieldType fieldType, ResultType source) → Future<String?>
Allows you to get a value of a text field based on a source type.
textFieldValueByTypeSourceOriginal(FieldType fieldType, ResultType source, bool original) → Future<String?>
Allows you to get a value of a text field based on a source type and its originality.
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Results?
Allows you to deserialize object.