ResultsStatus class

Provision of document verification status.

Constructors

ResultsStatus()

Properties

age → CheckResult
Summary of all age results.
no setter
ageStatus → AgeStatus
Container for an details age scanning statuses.
no setter
captureProcessIntegrity → CheckResult?
no setter
detailsOptical → OpticalStatus
Container for an optical related scanning statuses.
no setter
detailsRFID → RFIDStatus
Container for a RFID related scanning statuses.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mDL → CheckResult
Summary of all mDL results.
no setter
optical → CheckResult
Summary of all optical results. The same value as OpticalStatus.overallStatus
no setter
overallStatus → CheckResult
Summary of all results.
no setter
portrait → CheckResult
Comparison status for portrait in the document aganist live or external image.
no setter
rfid → CheckResult
Summary of all RFID results. Same as RFIDStatus.overallStatus.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stopList → CheckResult
Verification status for document data against database.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ResultsStatus?
Allows you to deserialize object.