ScannerConfig class

Properties

cameraId ↔ int?
Camera id.
getter/setter pair
extPortrait ↔ Uint8List?
Portrait photo from an external source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
livePortrait ↔ Uint8List?
Live portrait photo.
getter/setter pair
onlineProcessingConfig → OnlineProcessingConfig?
Configuration class for online processing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenario → Scenario?
Documents processing scenario.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ScannerConfig?