SecurityObject class

Structure is used to describe the contents of a single document security object (SO) and the results of its check within the context of the communication session with electronic document.

Constructors

SecurityObject()

Properties

fileReference → int
Reference to the source file of the security object data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
notifications → List<int>
The list of remarks occured during the scanning procedure.
no setter
objectType → String?
Security object identifier.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signerInfos → List<SignerInfo>
List of containers to store information about digital signature objects contained in the SO.
no setter
version → int
Security object version.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → SecurityObject?
Allows you to deserialize object.