SignerInfo class

Structure is used to store the result of the verification of a single digital signature of the number present in EF.SOD.

Constructors

SignerInfo()

Properties

certificateChain → List<CertificateChain>
Certificate chain, used for the digital signature verification.
no setter
dataToHash → String?
Data to hash.
no setter
digestAlgorithm → String?
Digital signature hash-function algorithm identifier.
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuer → Authority?
Identifier of the necessary certificate issuer.
no setter
notifications → List<int>
The list of remarks occured during the scanning procedure.
no setter
paStatus → int
Result of the digital signature verification.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → RFIDValue?
Serial number of the necessary certificate.
no setter
signature → RFIDValue?
Binary data of the verified digital signature.
no setter
signatureAlgorithm → String?
Digital signature algorithm identifier.
no setter
signedAttributes → List<Extension>
List of the signed attributes.
no setter
subjectKeyIdentifier → RFIDValue?
Signature object identifier of the necessary certificate.
no setter
version → int
Version of the digital signature data structure.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → SignerInfo?
Allows you to deserialize object.