StackTraceElement class

Constructors

StackTraceElement()

Properties

className ↔ String?
getter/setter pair
fileName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNativeMethod ↔ bool?
getter/setter pair
lineNumber ↔ int?
getter/setter pair
methodName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → StackTraceElement?