Symbol class

Structure describing single value of the field.

Constructors

Symbol()

Properties

code → int
ASCII code of symbol.
no setter
hashCode → int
The hash code for this object.
no setterinherited
probability → int
Symbol recognition probability (0–100, %).
no setter
rect → Rect?
Bounds result of the particular value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Symbol?
Allows you to deserialize object.