TccParams class

TCC service related parameters for RFID session configuration.

Constructors

TccParams()

Properties

hashCode → int
The hash code for this object.
no setterinherited
pfxCert ↔ ByteData?
The bytes of the certificate for a TCC service. This data will be used instead of loading the certificate via pfxCertUrl.
getter/setter pair
pfxCertUrl ↔ String?
The URL for the certificate for a TCC service. The value of the property must be a valid URL string.
getter/setter pair
pfxPassPhrase ↔ String?
The passphrase for the cerficiate provided by the pfxCertUrl property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceUrlPA ↔ String?
The PA URL for the TCC service. The value of the property must be a valid URL string.
getter/setter pair
serviceUrlTA ↔ String?
The TA URL for the TCC service. The value of the property must be a valid URL string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → TccParams?