TextField class

Serves for storing information from one text data field.

Constructors

TextField()

Properties

comparisonList → List<Comparison>
List of all comparison statuses for this field type.
no setter
comparisonStatus → CheckResult
Comparison result of the field.
no setter
fieldName → String
Textual field symbolic name.
no setter
fieldType → FieldType
Textual field logical type.
no setter
hashCode → int
The hash code for this object.
no setterinherited
lcid → LCID
ID of language-culture to differentiate one field of the same type from another (for example Belarus Passport Page # 31 – Belarusian and Russian fields of the same type).
no setter
lcidName → String
LCID symbolic name.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CheckResult
Textual field check result.
no setter
validityList → List<Validity>
List of all validity statuses for this field type.
no setter
validityStatus → CheckResult
Validity result of the field
no setter
value → String?
Value from the field.
no setter
values → List<Value>
An array of values.
no setter

Methods

getValue() → Value?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → TextField?
Allows you to deserialize object.