TextResult class

Structure, containing all text data extracted and recognized from the document.

Constructors

TextResult()

Properties

availableSourceList → List<TextSource>
List of all available origin source with overall validity status of all text fields of a particular source type.
no setter
comparisonStatus → CheckResult
Comparison status of all text fields.
no setter
fields → List<TextField>
An array of textual results.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CheckResult
Textual fields check result.
no setter
validityStatus → CheckResult
Validity status of all text fields.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → TextResult?
Allows you to deserialize object.