TextSource class

Structure describing single value of the field.

Constructors

TextSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
The value's origin source string description.
no setter
sourceType → ResultType
The value's origin source.
no setter
validityStatus → CheckResult
Overall validity status of all text fields of this source type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → TextSource?
Allows you to deserialize object.