VDSData class

Visible Digital Seal.

Constructors

VDSData()

Properties

certificate → String?
no setter
certificateChain → List<CertificateChain>
The certificate chain, used for the digital signature verification.
no setter
docFeatures → List<DocFeature>
The doc features.
no setter
docIssueDate → String?
no setter
docType → int?
no setter
featureRef → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuingCountry → String?
Three letter code identifying the issuing state or organization.
no setter
notifications → List<int>
The list of remarks occured during the scanning procedure.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → BytesData?
The binary data of the verified digital signature.
no setter
signatureDate → String?
no setter
signer → String?
no setter
type → int?
no setter
version → int?
Visible Digital Seal use case version.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → VDSData?
Allows you to deserialize object.