VDSNCData class

Visible Digital Seal for Non Constrained environments.

Constructors

VDSNCData()

Properties

certificate → BytesData?
The binary data of the signer certificate.
no setter
certificateChain → List<CertificateChain>
The certificate chain, used for the digital signature verification.
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuingCountry → String?
Three letter code identifying the issuing state or organization.
no setter
message → Map<String, dynamic>?
The message field contains the actual data as a dictionary (JSON).
no setter
notifications → List<int>
The list of remarks occured during the scanning procedure.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → BytesData?
The binary data of the verified digital signature.
no setter
signatureAlgorithm → String?
The signature algorithm used to produce the signature. ECDSA scheme.
no setter
type → String?
Visible Digital Seal use case type. Type is set to icao.test for Proof of Testing (data defined by CAPSCA), icao.vacc for Proof of Vaccination (data defined by WHO). Other Types may be added in the future.
no setter
version → int
Visible Digital Seal use case version.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → VDSNCData?
Allows you to deserialize object.