Value class

Structure describing single value of the field.

Constructors

Value()

Properties

boundRect → Rect?
Field rectangular area coordinates on the image.
no setter
hashCode → int
The hash code for this object.
no setterinherited
originalSymbols → List<Symbol>
List of all symbols for this value.
no setter
originalValue → String?
An original value.
no setter
pageIndex → int
An index of the document page whence the textual field is extracted.
no setter
probability → int
Textual field recognition probability (0 - 100, %).
no setter
rfidOrigin → RFIDOrigin?
RFID origin data. Only for the 'RFID' source.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → ResultType
Identifies zone whence data is extracted.
no setter
value → String?
A value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Value?
Allows you to deserialize object.