eCheckResult class

Constructors

eCheckResult()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CH_CHECK_ERROR → const int
CH_CHECK_OK → const int
CH_CHECK_WAS_NOT_DONE → const int