CertificateChain class

Constructors

CertificateChain()

Properties

extensions ↔ List<Extension?>
getter/setter pair
fileName ↔ Value?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuer ↔ Authority?
getter/setter pair
notifications ↔ List<int?>
getter/setter pair
origin ↔ int?
getter/setter pair
paStatus ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber ↔ String?
getter/setter pair
signatureAlgorithm ↔ String?
getter/setter pair
subject ↔ Authority?
getter/setter pair
subjectPKAlgorithm ↔ String?
getter/setter pair
type ↔ int?
getter/setter pair
validity ↔ Validity?
getter/setter pair
version ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CertificateChain?