CustomizationImages class

Constructors

CustomizationImages()

Properties

borderBackground ByteData?
getter/setter pair
captureButton ByteData?
getter/setter pair
closeButton ByteData?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
helpAnimation ByteData?
getter/setter pair
livenessAnimation ByteData?
getter/setter pair
mdlDisableNfcImage ByteData?
Android only.
getter/setter pair
mdlEnableNfcImage ByteData?
Android only.
getter/setter pair
mdlProcessingScreenFailureImage ByteData?
getter/setter pair
multipageButton ByteData?
getter/setter pair
nextPageIdCardBack ByteData?
getter/setter pair
nextPageIdCardFront ByteData?
getter/setter pair
nextPagePassportFlipBottom ByteData?
getter/setter pair
nextPagePassportFlipClean ByteData?
getter/setter pair
nextPagePassportFlipStart ByteData?
getter/setter pair
nextPagePassportFlipTop ByteData?
getter/setter pair
nextPagePassportShift ByteData?
getter/setter pair
rfidDisableNfcImage ByteData?
Android only.
getter/setter pair
rfidEnableNfcImage ByteData?
Android only.
getter/setter pair
rfidProcessingScreenFailureImage ByteData?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
switchButton ByteData?
getter/setter pair
testSetters Map<String, dynamic>
getter/setter pair
torchButtonOff ByteData?
getter/setter pair
torchButtonOn ByteData?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Allows you to serialize object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) CustomizationImages
Allows you to deserialize object.