CustomizationTimings class

Constructors

CustomizationTimings()

Properties

hashCode int
The hash code for this object.
no setterinherited
nextPageIdCardEndDelay int?
getter/setter pair
nextPageIdCardStartDelay int?
getter/setter pair
nextPagePassportFlipEndDelay int?
getter/setter pair
nextPagePassportFlipStartDelay int?
getter/setter pair
nextPagePassportShiftEndDelay int?
getter/setter pair
nextPagePassportShiftStartDelay int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testSetters Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Allows you to serialize object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) CustomizationTimings
Allows you to deserialize object.