File class

Constructors

File()

Properties

certificates ↔ SecurityObjectCertificates?
getter/setter pair
docFieldsGraphics ↔ List<int?>
getter/setter pair
docFieldsOriginals ↔ List<int?>
getter/setter pair
docFieldsText ↔ List<int?>
getter/setter pair
fileData ↔ FileData?
getter/setter pair
fileID ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notifications ↔ List<int?>
getter/setter pair
pAStatus ↔ int?
getter/setter pair
readingStatus ↔ int?
getter/setter pair
readingTime ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → File?