PDF417Info class

Constructors

PDF417Info()

Properties

columns → int
Number of columns in a barcode.
no setter
errorLevel → int
Barcode error correction level.
no setter
hashCode → int
The hash code for this object.
no setterinherited
rows → int
Number of rows in a barcode.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → PDF417Info?
Allows you to deserialize object.