RFIDApplicationType enum
Type of application of electronic document.
Values
- E_PASSPORT → const RFIDApplicationType
-
ePassport.
const RFIDApplicationType(1) - E_ID → const RFIDApplicationType
-
const RFIDApplicationType(2) - E_SIGN → const RFIDApplicationType
-
const RFIDApplicationType(3) - E_DL → const RFIDApplicationType
-
const RFIDApplicationType(4) - LDS2_TRAVEL_RECORDS → const RFIDApplicationType
-
Travel Records.
const RFIDApplicationType(5) - LDS2_VISA_RECORDS → const RFIDApplicationType
-
Visa Records.
const RFIDApplicationType(6) - LDS2_ADD_BIOMETRICS → const RFIDApplicationType
-
Add Biometrics.
const RFIDApplicationType(7) - E_DTC_PC → const RFIDApplicationType
-
eDTC PC.
const RFIDApplicationType(8)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getByValue(
int? i) → RFIDApplicationType?
Constants
-
values
→ const List<
RFIDApplicationType> - A constant List of the values in this enum, in order of their declaration.