SignerInfo class

Constructors

SignerInfo()

Properties

certificateChain ↔ List<CertificateChain?>
getter/setter pair
dataToHash ↔ String?
getter/setter pair
digestAlgorithm ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuer ↔ Authority?
getter/setter pair
notifications ↔ List<int?>
getter/setter pair
paStatus ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber ↔ Value?
getter/setter pair
signature ↔ Value?
getter/setter pair
signatureAlgorithm ↔ String?
getter/setter pair
signedAttributes ↔ List<Extension?>
getter/setter pair
subjectKeyIdentifier ↔ Value?
getter/setter pair
version ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → SignerInfo?